@@ -12,8 +12,8 @@ Authentication.h
 #include <stdio.h>
 #include <ctype.h>
 #include <signal.h>
-#include <db1/db.h>
 
+#include "xdb.h"
 #include "Utils.h"
 #include "Config.h"
 #include "Configuration.h"
@@ -21,21 +21,25 @@ Authentication.h
 #include "XVector.h"
 #include "Cookie.h"
 #include "CCLIENT.h"
+#include "ClientLDAP.h"
 
 typedef XVector<XString> StringList;
 
 class Authentication
   {
   private:
-    XString username, password, tmp_password, service, server;
+    XString username, password, tmp_password, server;
     int iservice, port;
     Cookie *cookie;
+    TBuffer ErrorString;
     bool IS_AUTHENTICATED;
     bool imap_authentication (void);
+    bool ldap_authentication (void);    
     void do_store_password (void);
   public:
-    Authentication (const char *aservice, const char *aserver, int aport, const char *ausername, const char *apassword, const char *connid);
+    Authentication (int aservice, const char *aserver, int aport, const char *ausername, const char *apassword, const char *connid);
     virtual ~Authentication ();
+    const char *getErrorMsg (void);   
     bool doFirstAuthentication (void);  
     const char *cookie_getSetFullCookieLine (void);
     const char *cookie_getSetClearFullCookieLine(void);    
