@@ -143,15 +143,15 @@ char *CCLIENT::getFullMailbox (char *amailbox, TBuffer resbuf)
   xstrncpy (mailbox, CMAXFILENAME, amailbox);
   if (NCstrstr (amailbox, NNTPFOLDERPREFIX) == 1) //Mailbox from News
     {
-    snprintf (resbuf, CMAXBUFFER, "{%s/nntp}%s", nntpserver, mailbox);
+    snprintf (resbuf, CMAXBUFFER, "{%s:%d/nntp}%s", nntpserver, nntpport, mailbox);
     }
   else if (strcmp (amailbox, "INBOX") == 0)
     {
-    snprintf (resbuf, CMAXBUFFER, "{%s/imap/user=\"%s\"}%s", imapserver, username, mailbox);
+    snprintf (resbuf, CMAXBUFFER, "{%s:%d/imap/user=\"%s\"}%s", imapserver, imapport, username, mailbox);
     }
   else
     {
-    snprintf (resbuf, CMAXBUFFER, "{%s/imap/user=\"%s\"}%s%s", imapserver, username, getPathToRemoteFolder(), mailbox);
+    snprintf (resbuf, CMAXBUFFER, "{%s:%d/imap/user=\"%s\"}%s%s", imapserver, imapport, username, getPathToRemoteFolder(), mailbox);
     }
   return resbuf;
   }  
@@ -355,8 +355,8 @@ void CCLIENT::setMaxLoginTrials (int amaxlogintrials)
   mail_parameters (NIL, SET_MAXLOGINTRIALS, (void *) maxlogintrials);
   }
 
-/*VALIDATE user/pw WITH IMAP. DO NOT OPEN A MAILBOX*/
-bool CCLIENT::IMAPValidate (const char *ahost, int aport, const char *amailbox, const char *ausername, const char *apassword)
+/*Authenticate user/pw WITH IMAP. DO NOT OPEN A MAILBOX*/
+bool CCLIENT::Authenticate (const char *ahost, int aport, const char *amailbox, const char *ausername, const char *apassword)
   {   
   TBuffer abuf;
   long flag;
@@ -369,6 +369,7 @@ bool CCLIENT::IMAPValidate (const char *ahost, int aport, const char *amailbox,
   xstrncpy (mailbox,  CMAXFILENAME, amailbox);
   xstrncpy (imapserver, CMAXIPNAME, ahost);
   xstrncpy (fullmailbox, CMAXFILENAME, getFullMailbox (mailbox, abuf));
+  //LOG ("--%s--", fullmailbox);
   if (strstr (fullmailbox, "/imap/") != NULL) ServerProtocol = PROTOCOL_IMAP; else ServerProtocol = PROTOCOL_NNTP;
   if (ServerProtocol == PROTOCOL_IMAP) 
     {
@@ -531,12 +532,15 @@ void CCLIENT::xmail_close (MAILSTREAM *stream)
   
 void CCLIENT::saveFlagsRCNewsFile (void)
   {
-  if (getStream()->dtb)
+  if (getStream() != NIL)
     {
-    if (!strcmp (getStream()->dtb->name, "nntp"))
+    if (getStream()->dtb)
       {
-      /*NNTP: I write flags from stream to local newsrc file*/
-      Newsrc_write (mailbox + strlen(NNTPFOLDERPREFIX), getStream());  
+      if (!strcmp (getStream()->dtb->name, "nntp"))
+        {
+        /*NNTP: I write flags from stream to local newsrc file*/
+        Newsrc_write (mailbox + strlen(NNTPFOLDERPREFIX), getStream());  
+        }
       }
     }
   } 
@@ -1110,7 +1114,7 @@ void CCLIENT::getHeaderList (xulong abeginmsg, StringList *SL, char *user, const
         // Debug: the offending MS Date: "        Thu, 5 Jul 2001 18:08:16 -0700";
         while (pc[0] == ' ') pc++;
         if (pc[strlen(pc) - 1] == ' ') pc[strlen(pc) - 1] = '\0';
-        mail_parse_date (&amc, pc);                        
+        mail_parse_date (&amc, (unsigned char *)pc);                        
         mail_date (tmp, &amc);  
         SL->Add (ProcesaDate (tmp, xtmp));
         }
@@ -1686,6 +1690,15 @@ bool CCLIENT::deleteMailbox (char *mailboxname)
   return false;    
   }
   
+bool CCLIENT::emptyMailbox (char *mailboxname)
+  {
+  bool b;
+  b = deleteMailbox (mailboxname);
+  if (b == false) return false;
+  b = createMailbox (mailboxname);
+  return b;  
+  }  
+  
 bool CCLIENT::renameMailbox (char *oldmailboxname, char *newmailboxname)
   {
   TBuffer abufold, abufnew, abuf;
