@@ -1,4 +1,4 @@
-/*
+/*      
 ClientDB.cc
 */
 
@@ -27,10 +27,11 @@ extern bool InverseDBSort;
 13. Optional 4
 */                
                 
-ClientDB::ClientDB (const char *adbfname, const char *adbdir, bool ReadOnly)
+ClientDB::ClientDB (const char *adbfname, const char *adbdir, bool ReadOnly, bool aUseIndex)
   {  
   db = NULL;
   dbindex = NULL;
+  UseIndex = aUseIndex;
   xstrncpy (dbdir, CMAXBUFFER, adbdir); addLastSlash (dbdir);
   xstrncpy (dbfname, CMAXBUFFER, dbdir); xstrncat (dbfname, CMAXBUFFER, adbfname);
   initStr (ErrorMsg);
@@ -65,17 +66,21 @@ bool ClientDB::DBopen (void)
   {
   initStr (ErrorMsg);
   db = dbopen (dbfname, DefOpenMode, DefCreateMode, DBType, NULL);
+  //DEBUG (dbfname);
   if (db == NULL) {xstrncpy (ErrorMsg, CMAXBUFFER, strerror(errno)); return false;}      
-  xstrncpy (dbindexfname, CMAXBUFFER, dbfname); xstrncat (dbindexfname, CMAXBUFFER, "."); xstrncat (dbindexfname, CMAXBUFFER, DB_INDEX_EXTENSION);
-  dbindex = dbopen (dbindexfname, DefOpenMode, DefCreateMode, DBType, NULL);
-  if (dbindex == NULL) 
+  if (UseIndex == true)
     {
-    if (!generaIndexFromDB (dbfname, dbindexfname, ErrorMsg)) {return false;}
+    xstrncpy (dbindexfname, CMAXBUFFER, dbfname); xstrncat (dbindexfname, CMAXBUFFER, "."); xstrncat (dbindexfname, CMAXBUFFER, DB_INDEX_EXTENSION);
     dbindex = dbopen (dbindexfname, DefOpenMode, DefCreateMode, DBType, NULL);
-    if (dbindex == NULL)
+    if (dbindex == NULL) 
       {
-      xstrncpy (ErrorMsg, CMAXBUFFER, strerror(errno)); return false;
-      }
+      if (!generaIndexFromDB (dbfname, dbindexfname, ErrorMsg)) {return false;}
+      dbindex = dbopen (dbindexfname, DefOpenMode, DefCreateMode, DBType, NULL);
+      if (dbindex == NULL)
+        {
+        xstrncpy (ErrorMsg, CMAXBUFFER, strerror(errno)); return false;
+        }
+      }  
     }    
   if (obtainDBInfo() == false) {return false;}
   //displayDBStructure (NULL);
@@ -89,10 +94,14 @@ bool ClientDB::DBclose (void)
   int ret;
   delete dbinfo.MatField;
   initStr (ErrorMsg);
+  Sync();      
   ret = db->close(db);
   db = NULL;
-  ret = dbindex->close(dbindex);
-  dbindex = NULL;
+  if (UseIndex == true) 
+    {
+    ret = dbindex->close(dbindex);
+    dbindex = NULL;
+    }
   return true;  
   }
 
@@ -101,7 +110,7 @@ int ClientDB::getTotalNumRecords (void)
   int rval, reccount = 0;
   DBT key, data;
   if (db == NULL) return -1;
-  if (dbindex == NULL) return -1;  
+  if (UseIndex == true) {if (dbindex == NULL) return -1;}
   rval = db->seq (db, &key, &data, R_FIRST);
   while (!rval)
     {
@@ -117,7 +126,7 @@ int ClientDB::getNumRecords (void)
   return dbinfo.dbreccount;
   }
 
-bool ClientDB::incRecordCount (TUniqId uniqid)
+bool ClientDB::incRecordCount (const TUniqId uniqid)
   {
   int ires;
   TNumber anum;
@@ -131,12 +140,15 @@ bool ClientDB::incRecordCount (TUniqId uniqid)
   
   ++dbinfo.dbreccount;
 
-  xitoa (dbinfo.dbreccount, anum);
-  dkey.data = (void *)anum; dkey.size = strlen (anum);
-  ddata.data = (void *)uniqid;  ddata.size = strlen (uniqid);
-  ires = dbindex->put (dbindex, &dkey, &ddata, 0);
-  if (ires < 0) {xsnprintf (ErrorMsg, CMAXBUFFER, "incRecordCount: %s", strerror(errno)); return false;}  
-
+  if (UseIndex == true)
+    {
+    xitoa (dbinfo.dbreccount, anum);
+    dkey.data = (void *)anum; dkey.size = strlen (anum);
+    ddata.data = (void *)uniqid;  ddata.size = strlen (uniqid);
+    ires = dbindex->put (dbindex, &dkey, &ddata, 0);
+    if (ires < 0) {xsnprintf (ErrorMsg, CMAXBUFFER, "incRecordCount: %s", strerror(errno)); return false;}  
+    }
+    
   return true;
   }
 
@@ -178,12 +190,57 @@ bool ClientDB::generaUniqID (TUniqId uniqid)
   return true;
   }
   
+//Return a legal uniqid, not empty necessary  
+bool ClientDB::generaIDFromPos (int pos, TUniqId uniqid)
+  {
+  TNumber anum;
+  int L;
+    
+  memset (uniqid, int('0'), CMAXUNIQID);  
+  xitoa (pos, anum);  
+  L = strlen(anum);
+  for (int i = 0; i < (signed int)L; ++i)
+    {
+    uniqid[CMAXUNIQID + i - L] = anum[i];
+    }  
+  uniqid[CMAXUNIQID] = '\0';    
+  return existsRecord (uniqid);
+  }  
+  
+bool ClientDB::existsRecord (TUniqId uniqid)
+  {
+  DBT dkey, ddata;
+  int ires;
+  TBuffer abuf;
+  
+  if (db == NULL) return false;  
+
+  xstrncpy (abuf, CMAXBUFFER, uniqid);
+  xstrncat (abuf, CMAXBUFFER, "_");
+  xstrncat (abuf, CMAXBUFFER, DB_FLAGRECORD_NAME);
+    
+  dkey.data = (void *)abuf; dkey.size = strlen(abuf);
+  ires = db->get (db, &dkey, &ddata, 0);
+  if (ires == 1) 
+    {
+    return false;
+    } 
+  else if (ires < 0) 
+    {
+    return false;
+    }
+  else
+    {
+    return true;
+    }
+  }
+  
 void ClientDB::displayDBInfo (XSocket *aXS)
   {
   if (aXS == NULL)
     {
     DEBUG ("Information for db file    =%s", dbfname); 
-    DEBUG ("          db index file    =%s", dbindexfname);    
+    if (UseIndex == true) {DEBUG ("          db index file    =%s", dbindexfname);}
     DEBUG ("-------------------------------------------------------");
     DEBUG ("              DBVersion    =%s", dbinfo.dbversion);
     DEBUG ("              DBName       =%s", dbinfo.dbname);  
@@ -200,7 +257,7 @@ void ClientDB::displayDBInfo (XSocket *aXS)
     {
     TBuffer abuf;
     xsnprintf (abuf, CMAXBUFFER, "Information for db file    =%s\n", dbfname); aXS->Write (abuf, strlen(abuf));
-    xsnprintf (abuf, CMAXBUFFER, "          db index file    =%s\n", dbindexfname); aXS->Write (abuf, strlen(abuf));   
+    if (UseIndex == true) {xsnprintf (abuf, CMAXBUFFER, "          db index file    =%s\n", dbindexfname); aXS->Write (abuf, strlen(abuf));}
     xsnprintf (abuf, CMAXBUFFER, "-------------------------------------------------------\n"); aXS->Write (abuf, strlen(abuf));
     xsnprintf (abuf, CMAXBUFFER, "              DBVersion    =%s\n", dbinfo.dbversion); aXS->Write (abuf, strlen(abuf));
     xsnprintf (abuf, CMAXBUFFER, "              DBName       =%s\n", dbinfo.dbname); aXS->Write (abuf, strlen(abuf)); 
@@ -309,9 +366,9 @@ bool ClientDB::parseDBPermissions (void)
 
 bool ClientDB::Sync (void)
   {
-  int iret1, iret2;
+  int iret1 = 0, iret2 = 0;
   iret1 = db->sync (db, 0);
-  iret2 = dbindex->sync (dbindex, 0);
+  if (UseIndex == true) {iret2 = dbindex->sync (dbindex, 0);}
   if ((iret1 != 0) || (iret2 != 0)) return false;
   return true;
   }
@@ -543,6 +600,8 @@ char *ClientDB::getUniqIDFromIndexPos (int pos, TUniqId uniqid)
   TNumber anum;
   DBT dkey, ddata;
   int ires, L;
+ 
+  if (UseIndex == false) return NULL;
   
   if (dbindex == NULL) return NULL;  
   //if ((pos <= 0) || (pos > getNumRecords())) {xsnprintf (ErrorMsg, CMAXBUFFER, "getUniqIDFromIndexPos: Error: Invalid pos"); return NULL;}
@@ -570,7 +629,7 @@ char *ClientDB::getField_Text_ByID (TUniqId uniqid, TFieldName fieldname, char *
   DBT dkey, ddata;
   int ires; 
 
-  *len = -1; if (db == NULL) return NULL;  if (dbindex == NULL) return NULL;  
+  *len = -1; if (db == NULL) return NULL;  if (UseIndex == true) if (dbindex == NULL) return NULL;  
   if (!isFieldName(fieldname)) {xsnprintf (ErrorMsg, CMAXBUFFER, "getField_Text_ByID: Error: No field %s", fieldname); return NULL;}
 
   xsnprintf (id, CMAXBUFFER, "%s_%s", uniqid, fieldname);  
@@ -593,7 +652,7 @@ char *ClientDB::displayField_Text_ByID (TUniqId uniqid, TFieldName fieldname, TT
   int ires, lendata; 
   char *dataname;
 
-  *len = -1; if (db == NULL) return NULL;  if (dbindex == NULL) return NULL;  
+  *len = -1; if (db == NULL) return NULL;  if (UseIndex == true) if (dbindex == NULL) return NULL;  
   if (!isFieldName(fieldname)) {xsnprintf (ErrorMsg, CMAXBUFFER, "displayField_Text_ByID: Error: No field %s", fieldname); return NULL;}
 
   if (fieldtype == fURL)
@@ -641,12 +700,12 @@ char *ClientDB::displayField_Text_ByID (TUniqId uniqid, TFieldName fieldname, TT
   return data;  
   }
 
-bool ClientDB::putField_Text_ByID (TUniqId uniqid, TFieldName fieldname, char *data, int len)
+bool ClientDB::putField_Text_ByID (const TUniqId uniqid, TFieldName fieldname, char *data, int len)
   {
   TBuffer id;
   DBT dkey, ddata;
   int ires; 
-  if (db == NULL) return false;  if (dbindex == NULL) return false;  
+  if (db == NULL) return false;  if (UseIndex == true) if (dbindex == NULL) return false;  
   if (!isFieldName(fieldname)) {xsnprintf (ErrorMsg, CMAXBUFFER, "putField_Text_ByID: Error: No field %s", fieldname); return false;}
   xsnprintf (id, CMAXBUFFER, "%s_%s", uniqid, fieldname);  
   if (isRecordReserved (id) == true) {xsnprintf (ErrorMsg, CMAXBUFFER, "putField_Text_ByID: Error: Record is reserved"); return false;}
@@ -698,6 +757,8 @@ int ClientDB::deleteIDsFromIndex (StringList *SLIDItems)
   TBuffer abuf, abuf2;
   StringList SL;
   
+  if (UseIndex == false) return 0;
+  
   SL.Clear();
   rval = dbindex->seq (dbindex, &dkey, &ddata, R_FIRST);
   while (!rval)
@@ -741,6 +802,7 @@ bool ClientDB::pasteItems (StringList *SLPapeleraCopy, StringList *SLPapeleraCut
 
 bool ClientDB::openIndex (void)
   {
+  if (UseIndex == false) return false;  
   dbindex = dbopen (dbindexfname, DefOpenMode, DefCreateMode, DBType, NULL);
   if (dbindex == NULL) {xstrncpy (ErrorMsg, CMAXBUFFER, strerror(errno)); return false;}    
   return true;
@@ -748,6 +810,7 @@ bool ClientDB::openIndex (void)
 
 bool ClientDB::closeIndex (void)
   {
+  if (UseIndex == false) return false;
   dbindex->close(dbindex);
   dbindex = NULL;
   return true;
@@ -764,7 +827,7 @@ void CDB_FlipEntries (const void *e1, const void *e2)
   {
   TDBNodo temp;
   temp.key    = PDBNodo (e1)->key;
-  temp.uniqid = PDBNodo (e1)->uniqid;  
+  temp.uniqid = PDBNodo (e1)->uniqid;
   temp.value  = PDBNodo (e1)->value;
   PDBNodo (e1)->key    = PDBNodo (e2)->key;    PDBNodo (e2)->key   = temp.key;
   PDBNodo (e1)->uniqid = PDBNodo (e2)->uniqid; PDBNodo (e2)->uniqid = temp.uniqid;    
@@ -779,6 +842,8 @@ bool ClientDB::compactIndex (void)
   DBT dkey, ddata;
   TDBNodo dbnodo;
   
+  if (UseIndex == false) return false;
+    
   if (db == NULL) return false; if (dbindex == NULL) return false;  
 
   dbnodolist.Clear();
@@ -929,6 +994,38 @@ bool ClientDB::SaveRecordFromCGI (const char *envfile, char *recordid)
   return true; 
   }  
 
+bool ClientDB::SaveRecordFixedIdFromCGI (const char *envfile, const char *recordid)    
+  {
+  TDBField DBField;  
+  TBuffer abuf;
+  char *pc;
+
+  if (!checkValidRecord (envfile)) {return false;};
+  for (int i = 0; i < getNumFields(); ++i)
+    {
+    //DEBUG ("DBField.fname=--%s--", DBField.fname);
+    DBField = dbinfo.MatField->elementAt(i);
+    if (DBField.ftype == fTEXT)
+      {
+      (const char *)pc = cgienv_GetComplexVar (envfile, DBField.fname);
+      if (!putField_Text_ByID (recordid, DBField.fname, pc, strlen(pc))) return false;
+      }
+    else if (DBField.ftype == fRESERVED)
+      {  
+      strcpy (abuf, DBField.fdefault);
+      if (!putField_Text_ByID (recordid, DBField.fname, abuf, strlen(abuf))) return false;                
+      }        
+    else
+      {  
+      cgienv_GetSimpleVarDef (envfile, DBField.fname, abuf, "");
+      if (!putField_Text_ByID (recordid, DBField.fname, abuf, strlen(abuf))) return false;
+      }
+    }
+  incRecordCount (recordid);  
+  Sync();  
+  return true; 
+  } 
+
 bool ClientDB::generaHTMLFormEditNewRecord (StringList *SLHTML)
   {
   TDBField DBField;  
@@ -1203,11 +1300,13 @@ bool ClientDB::Sort (TFieldName fieldname)
   TType fieldtype;
   TNumber anum;
 
+  if (UseIndex == false) return false;    
+
   fieldtype = getTypeFromString (fieldname);
   if (InverseDBSort == true) InverseDBSort = false; else InverseDBSort = true;
   dbnodolist.Clear();
   if (db == NULL) return false;
-  if (dbindex == NULL) return false;  
+  if (UseIndex == true) if (dbindex == NULL) return false;  
   rval = dbindex->seq (dbindex, &dkey, &ddata, R_FIRST);
   while (!rval)
     {
@@ -1344,14 +1443,16 @@ int ClientDB::deleteRecordsByID (StringList *SLUniqIDItems)
       {
       DBField = dbinfo.MatField->elementAt(j);
       xsnprintf (af, CMAXBUFFER, "%s_%s", SLUniqIDItems->getString(i).cstr(), DBField.fname);
+      //DEBUG ("i=%d,j=%d,af=%s", i, j, af);
       dkey.data  = (void *)af; dkey.size = strlen(af);
       ires = db->del (db, &dkey, 0);
       }
     if (!delRecordCount ()) {return -1;}      
     ++ret;
     }
+  Sync();  
   deleteIDsFromIndex (SLUniqIDItems);  
-  if (!compactIndex ()) {return -1;} 
+  if (UseIndex == true) {if (!compactIndex ()) {return -1;}}
   return ret;  
   }              
 
@@ -1466,6 +1567,35 @@ bool ClientDB::Search (TFieldName fieldname, const char *whatsearch, StringList
   return true;
   }
  
+bool ClientDB::isRightIndexPos (int pos, TUniqId uniqid)
+  {
+  TNumber anum;
+  DBT dkey, ddata;
+  int ires, L;
+  
+  if (UseIndex == false) return false;    
+  
+  initStr (uniqid);
+  if ((db == NULL) || (dbindex == NULL)) return false;  
+
+  xitoa (pos, anum);
+  dkey.data = (void *)anum; dkey.size = strlen(anum);
+  ires = dbindex->get (dbindex, &dkey, &ddata, 0);
+  if (ires == 1) 
+    {
+    return false;
+    } 
+  else if (ires < 0) 
+    {
+    return false;
+    }
+  L = ddata.size;
+  memcpy (uniqid, ddata.data, ddata.size);
+  uniqid[L] = '\0';  
+    
+  return true;
+  }
+
 bool Match (const char *pc, const char *whatsearch)
   {
   if (IsEmpty(whatsearch)) return false;
@@ -1664,7 +1794,7 @@ bool dumpDatabase (const char *dbuserpath, const char *dbfn, TBuffer sterror, XS
     
   initStr(sterror);
 
-  acdb = new ClientDB (dbfn, dbuserpath, true);
+  acdb = new ClientDB (dbfn, dbuserpath, true, true);
   acdb->DBopen();
   acdb->displayDBInfo (aXS);
   acdb->displayDBStructure (aXS);
