@@ -488,7 +488,7 @@ bool ClientFileBrowser::changeAbsDir (const char *anewdir)
       lstat (buf, &statbuf);      
       xstrncpy (xf.FileName, CMAXFILENAME, ent->d_name);
       xf.size     = statbuf.st_size;
-      xf.st_mtime = statbuf.st_mtime;
+      xf.stmtime  = statbuf.st_mtime;
       xf.type     = statbuf.st_mode & S_IFMT;      
       xf.Copiado  = false; 
       xf.Cortado  = false; 
@@ -995,13 +995,13 @@ void CFB_FlipEntries (const void *e1, const void *e2)
   XFile temp;
   temp.FileName  = PXFile (e1)->FileName;
   temp.size      = PXFile (e1)->size;
-  temp.st_mtime  = PXFile (e1)->st_mtime;
+  temp.stmtime  = PXFile (e1)->stmtime;
   temp.type      = PXFile (e1)->type;  
   temp.Copiado   = PXFile (e1)->Copiado;    
   temp.Cortado   = PXFile (e1)->Cortado;    
   PXFile (e1)->FileName  = PXFile (e2)->FileName;  PXFile (e2)->FileName  = temp.FileName;
   PXFile (e1)->size      = PXFile (e2)->size;      PXFile (e2)->size      = temp.size;  
-  PXFile (e1)->st_mtime  = PXFile (e2)->st_mtime;  PXFile (e2)->st_mtime  = temp.st_mtime;  
+  PXFile (e1)->stmtime  = PXFile (e2)->stmtime;  PXFile (e2)->stmtime  = temp.stmtime;  
   PXFile (e1)->type      = PXFile (e2)->type;      PXFile (e2)->type      = temp.type;  
   PXFile (e1)->Copiado   = PXFile (e2)->Copiado;   PXFile (e2)->Copiado   = temp.Copiado;  
   PXFile (e1)->Cortado   = PXFile (e2)->Cortado;   PXFile (e2)->Cortado   = temp.Cortado;  
@@ -1033,7 +1033,7 @@ int CFB_CompareEntriesByFileSize  (const void *e1, const void *e2)
 int CFB_CompareEntriesByFileDate  (const void *e1, const void *e2)
   {
   int res;
-  res = PXFile (e1)->st_mtime - PXFile(e2)->st_mtime;
+  res = PXFile (e1)->stmtime - PXFile(e2)->stmtime;
   if (Inverse == true) {res = (-1) * res;}
   return res;  
   }
