@@ -38,7 +38,7 @@ ClientTIMSIEVED::ClientTIMSIEVED (const char *aserver, int aport, const char *au
   xstrncpy (pw, CMAXBUFFER, apw);
   timsievedport = aport;
 
-  xstrncpy (sievefile, CMAXIPNAME, asievefile);
+  xstrncpy (sievefile, CMAXBUFFER, asievefile);
   ConfSieve = new Configuration (sievefile, false);
   ConfSieve->ConfRead ();
 
@@ -230,6 +230,49 @@ bool ClientTIMSIEVED::saveAntiSpamFilterToFile (const char *fncgi, const char *s
   return true;
   }  
 
+/*
+   require ["fileinto"];
+   
+   if allof (header :contains  "X-RBL-Warning" "Warning") {
+        fileinto "INBOX.SPAM";
+   }
+   
+   else {
+        keep;
+   }
+*/  
+bool ClientTIMSIEVED::saveAntiSpamFilterToFile2 (const char *fncgi, const char *spammailbox)
+  {
+  XString XS;
+  bool b;
+  XFilter afilter;
+  
+  initStr (ErrorMsg);
+
+  xsnprintf (afilter.sectionname, CMAXBUFFER, "filter_%d", ConfSieve->getFreeSlot("filter_%d", CMAXFILTERS));
+
+  xstrncpy (afilter.name, CMAXBUFFER, PREDEF_ANTISPAMFILTERNAME2);
+  b = ConfSieve->setString (afilter.sectionname, "name", afilter.name, 500);
+
+  xstrncpy (afilter.header_name, CMAXBUFFER, "X-RBL-Warning");    
+  b = ConfSieve->setString (afilter.sectionname, "header_name", afilter.header_name, 500);
+
+  xstrncpy (afilter.header_value, CMAXBUFFER, "Warning");    
+  b = ConfSieve->setString (afilter.sectionname, "header_value", afilter.header_value, 500);
+
+  xstrncpy (afilter.folder, CMAXBUFFER, spammailbox);    
+  b = ConfSieve->setString (afilter.sectionname, "folder", afilter.folder, 500);
+
+  xstrncpy (afilter.action, CMAXBUFFER, "move");        
+  b = ConfSieve->setString (afilter.sectionname, "action", afilter.action, 500);
+
+  b = ConfSieve->Sync ();
+  
+  loadFiltersFromFile();
+
+  return true;
+  }  
+
 bool ClientTIMSIEVED::upSection (const char *secname)
   {
   TBuffer abuf;
@@ -414,6 +457,7 @@ bool ClientTIMSIEVED::doSession (int sieve_cmd, TBuffer scriptname, StringList *
 
   /*ENVIO AUTH PLAIN*/
   snprintf (buffer, CMAXBUFFER, "AUTHENTICATE \"plain\" \"%s\"\n", base64);
+  //fprintf (stderr, "%s", buffer);
   if (socket->Puts (buffer) == -1) {return false;}
   /*LEO LO RECIBIDO*/
   while ((b = socket->Gets (buffer, sizeof(buffer)-1)) == true)
@@ -490,9 +534,11 @@ bool ClientTIMSIEVED::doSession (int sieve_cmd, TBuffer scriptname, StringList *
       {
       xsnprintf (buffer, CMAXBUFFER, "PUTSCRIPT \"%s\" {%d+}\r\n", scriptname, strlen(data2put));
       if (socket->Puts (buffer) == -1) {return false;}
+      //fprintf (stderr, "%s", buffer);
       
       xsnprintf (buffer, CMAXBUFFER, "%s\r\n", data2put);
       if (socket->Puts (buffer) == -1) {return false;}
+      //fprintf (stderr, "%s", buffer);
       
       //LEO LO RECIBIDO
       while ((b = socket->Gets (buffer, sizeof(buffer)-1)) == true)
@@ -501,13 +547,18 @@ bool ClientTIMSIEVED::doSession (int sieve_cmd, TBuffer scriptname, StringList *
         if (strcmp (buffer, "OK") == 0) break;
         else if (NCstrstr(buffer, "NO ") == 1) 
           {
-          if (strstr("{", buffer) != NULL) 
+          if (strstr(buffer, "{") != NULL) 
             {
-            //READ THE SECOND ERROR LINE
-            socket->Gets (buffer, sizeof(buffer)-1);
-            xstrncpy (ErrorString, CMAXBUFFER, buffer); 
+            //READ THE SECOND AND THIRD ERROR LINE
+            socket->Gets (buffer, sizeof(buffer)-1); xstrncpy (ErrorString, CMAXBUFFER, buffer); 
+            socket->Gets (buffer, sizeof(buffer)-1); xstrncat (ErrorString, CMAXBUFFER, buffer);             
             return false;
             }
+          else
+            {
+            xstrncpy (ErrorString, CMAXBUFFER, buffer);
+            return false;
+            }  
           break;
           }
         else SLRes->Add (buffer);
@@ -532,6 +583,17 @@ bool ClientTIMSIEVED::doSession (int sieve_cmd, TBuffer scriptname, StringList *
   return true;
   }
 
+bool ClientTIMSIEVED::isThereFilter (const char *filtername)
+  {
+  XFilter afilter;  
+  for (int i = 0; i < FLAllFilters.Count(); ++i)
+    {
+    afilter = FLAllFilters.elementAt(i);
+    if (strcmp (afilter.name, filtername) == 0) {return true;}
+    }
+  return false;
+  }
+  
 void ClientTIMSIEVED::makeSieveScript (char *sieveprogram, int MAXLENGTH)
   {
   XString XS;
@@ -540,14 +602,49 @@ void ClientTIMSIEVED::makeSieveScript (char *sieveprogram, int MAXLENGTH)
   TBuffer tmp;
   XFilter filter;
 
-  xstrncpy (sieveprogram, MAXLENGTH, "#CREATED BY POSTMAN 2.0\n");
-  xstrncat (sieveprogram, MAXLENGTH, "require [\"fileinto\",\"reject\",\"vacation\",\"notify\",\"subaddress\",\"regex\"];\n");
-  xstrncat (sieveprogram, MAXLENGTH, "\n");      
-  
-  //FILTERS
   totfilters = FLAllFilters.Count();
+  initStr(sieveprogram);
+  xstrncpy (sieveprogram, MAXLENGTH, "#CREATED BY POSTMAN 2.0\n");
+  if ((strcasecmp (vacation.vacations_active, "true") == 0) || (totfilters > 0))
+    {
+    xstrncat (sieveprogram, MAXLENGTH, "require [\"vacation\",\"fileinto\",\"reject\",\"notify\",\"subaddress\",\"regex\"];\n");
+    }
+  xstrncat (sieveprogram, MAXLENGTH, "\n");      
+
+  //VACATIONS
+  if (strcasecmp (vacation.vacations_active, "true") == 0)
+    {
+    xstrncat (sieveprogram, MAXLENGTH, "#VACATIONS\n");
+    SeparaTokensEnStringList (vacation.vacations_ausenstaddresses, '\n', &SL);
+    if (SL.Count() > 0)
+      {
+      initStr (vacation.vacations_ausenstaddresses);
+      for (int j=0; j < SL.Count(); ++j)
+        {                           
+        xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, "\"");
+        xstrncpy (tmp, CMAXBUFFER, SL.getString(j).cstr());
+        QuitaRetornoCarroDeLinea (tmp);
+        QuitaComillas (tmp);
+        xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, tmp);
+        xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, "\"");      
+        if (j < SL.Count() - 1) {xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, ",");}
+        }
+      xsnprintf (tmp, CMAXBUFFER, "vacation :days %s :addresses [%s] :subject \"%s\" text:\n", 
+                 vacation.vacations_days2repeat, vacation.vacations_ausenstaddresses, vacation.vacations_msgsubject);
+      }
+    xstrncat (sieveprogram, MAXLENGTH, tmp);     
+    xstrncat (sieveprogram, MAXLENGTH, vacation.vacations_msgtext);
+    xstrncat (sieveprogram, MAXLENGTH, "\n.\n;\n");
+    }
+  else
+    {
+    xstrncat (sieveprogram, MAXLENGTH, "#VACATIONS\n");
+    }  
+
+  //FILTERS
   if (totfilters > 0)
     {
+    xstrncat (sieveprogram, MAXLENGTH, "\n#FILTERS\n");
     for (numfilter = 0; numfilter < totfilters; ++numfilter)
       {
       filter = FLAllFilters.elementAt(numfilter);
@@ -633,41 +730,12 @@ void ClientTIMSIEVED::makeSieveScript (char *sieveprogram, int MAXLENGTH)
     xstrncat (sieveprogram, MAXLENGTH,   "  }\n");                  
     xstrncat (sieveprogram, MAXLENGTH, "\n");      
     }
-    
-  //VACATIONS
-  xstrncat (sieveprogram, MAXLENGTH, "#VACATIONS\n");
-  if (strcasecmp (vacation.vacations_active, "true") == 0)
-    {
-    SeparaTokensEnStringList (vacation.vacations_ausenstaddresses, '\n', &SL);
-    if (SL.Count() > 0)
-      {
-      initStr (vacation.vacations_ausenstaddresses);
-      for (int j=0; j < SL.Count(); ++j)
-        {                           
-        xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, "\"");
-        xstrncpy (tmp, CMAXBUFFER, SL.getString(j).cstr());
-        QuitaRetornoCarroDeLinea (tmp);
-        xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, tmp);
-        xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, "\"");      
-        if (j < SL.Count() - 1) {xstrncat (vacation.vacations_ausenstaddresses, CMAXBUFFER, ",");}
-        }
-      xsnprintf (tmp, CMAXBUFFER, "vacation :days %s :addresses [%s] :subject \"%s\" text:\n", 
-                 vacation.vacations_days2repeat, vacation.vacations_ausenstaddresses, vacation.vacations_msgsubject);
-      }
-    else
-      {                          
-      xsnprintf (tmp, CMAXBUFFER, "vacation :days %s :subject \"%s\" text:\n", 
-                 vacation.vacations_days2repeat, vacation.vacations_msgsubject);
-      }
-    xstrncat (sieveprogram, MAXLENGTH, tmp);     
-    xstrncat (sieveprogram, MAXLENGTH, vacation.vacations_msgtext);
-    xstrncat (sieveprogram, MAXLENGTH, "\n.\n;\n");
-    }
+
   xstrncat (sieveprogram, MAXLENGTH, "\n");   
   XS = sieveprogram;
   XS.replace ("\r\n", "\n");
   xstrncpy (sieveprogram, MAXLENGTH, XS.cstr());
-
+    
   //fprintf (stderr, "%s", sieveprogram);   
   }
 
@@ -678,20 +746,15 @@ bool ClientTIMSIEVED::saveSieveNetwork (void)
   bool b;
   
   makeSieveScript (sieveprogram, CMAXHBUFFER);
+  //fprintf (stderr, "1 saveSieveNetwork,sieveprogram=%s", sieveprogram);
   b = doSession (SIEVE_CMD_PUTSCRIPT, POSTMANSIEVEFILTERNAME, &SLRes, sieveprogram, ErrorMsg);
   if (b == false) {return false;};
+  //fprintf (stderr, "2 saveSieveNetwork,sieveprogram=%s", sieveprogram);
   b = doSession (SIEVE_CMD_SETACTIVE, POSTMANSIEVEFILTERNAME, &SLRes, NULL, ErrorMsg);
   if (b == false) {return false;};
+  //fprintf (stderr, "3 saveSieveNetwork,sieveprogram=%s", sieveprogram);
   return true;
   }
 
-bool ClientTIMSIEVED::isThereFilter (const char *filtername)
-  {
-  XFilter afilter;  
-  for (int i = 0; i < FLAllFilters.Count(); ++i)
-    {
-    afilter = FLAllFilters.elementAt(i);
-    if (strcmp (afilter.name, filtername) == 0) {return true;}
-    }
-  return false;
-  }
+  
+  
