@@ -801,6 +801,12 @@ void HTMLBasic::PrintConfirmPage (int service, const char *stcmd, const char *st
                         RedLabel (abuff); 
                         break;
                         }
+    case CMD_CCLIENT_MB_CLEAR: 
+                        {
+                        snprintf (abuff, CMAXBUFFER, L->get(MSG_CONF_CLEARMAILBOX), tokentodelete); 
+                        RedLabel (abuff); 
+                        break;
+                        }                        
     case CMD_CCLIENT_MB_EXPUNGE: 
                         {
                         RedLabel (L->get(MSG_CONF_EXPUNGE));
@@ -840,6 +846,7 @@ void HTMLBasic::PrintConfirmPage (int service, const char *stcmd, const char *st
   FormHidden ("pageid", pageid);
   FormHidden ("lastcmd", CMD_MAIN_CONF_ACT);
   if (cmd == CMD_CCLIENT_MB_DELETE) {FormHiddenQuoted ("mailboxname", tokentodelete);}  
+  else if (cmd == CMD_CCLIENT_MB_CLEAR) {FormHiddenQuoted ("mailboxname", tokentodelete);}  
   else if (cmd == CMD_DATABASES_DB_DELETE) {FormHiddenQuoted ("db_delete_name", tokentodelete);}
   else if (cmd == CMD_SIEVE_FILTERS_DELETE) {FormHiddenQuoted ("filters_to_delete", tokentodelete);}  
   FormButton ("theaction", L->get(L_CONFIRM));    
