@@ -22,11 +22,13 @@ TBuffer fnsocket, tmp, abuf;
 
 extern bool Service_FileBrowser_Initialized;
 extern bool Service_SecVirtual_Initialized;
+extern bool Service_Dotlearn_Initialized;
 extern bool Service_Databases_Initialized;
 extern bool Service_UserAccounts_Initialized;
 extern bool Service_Config_Initialized;
 extern bool Service_Sieve_Initialized;
 extern bool Service_Calendar_Initialized;
+extern bool Service_Cclient_Initialized;
 
 int main  (int argc, char **argv, char **envp)
   {
@@ -199,13 +201,18 @@ int ChildLoop (int way)
         LOOP_FINISHED = DoService_Main_CMD (&pd);
         if (pd.cmd == CMD_MAIN_LOGOUT) 
           {
-          if (Service_FileBrowser_Initialized == true) DoService_FileBrowser_END (&pd);
+          if (Service_Cclient_Initialized == true) DoService_Cclient_END (&pd);
+          if (Service_FileBrowser_Initialized == true) DoService_FileBrowser_END (&pd);          
           if (Service_Databases_Initialized == true) DoService_Databases_END (&pd);
           }
         break; 
         }   
       case iSERVICE_CCLIENT:
         {
+        if (Service_Cclient_Initialized == false) 
+          {
+          if (DoService_Cclient_BEGIN (&pd) == false) {break;}
+          }    
         LOOP_FINISHED = DoService_Cclient_CMD (&pd);
         break;
         }
@@ -232,6 +239,15 @@ int ChildLoop (int way)
         LOOP_FINISHED = DoService_SecVirtual_CMD (&pd);
         break;                        
         }
+      case iSERVICE_DOTLEARN:
+        {
+        if (Service_Dotlearn_Initialized == false) 
+          {
+          if (DoService_Dotlearn_BEGIN (&pd) == false) {break;}
+          }          
+        LOOP_FINISHED = DoService_Dotlearn_CMD (&pd);
+        break;                        
+        }        
       case iSERVICE_POPPASS:
         {
         LOOP_FINISHED = DoService_PopPass_CMD (&pd);
@@ -555,7 +571,7 @@ void ExitServer (void)
 void ErrorInLogin (void)
   {
   TBuffer errmsg;
-  xstrncpy (errmsg, CMAXBUFFER, cclient->getErrorString());
+  xstrncpy (errmsg, CMAXBUFFER, auth->getErrorMsg());
   LOG ("%s (pd.ipclient='%s', user='%s')", errmsg, pd.ipclient, pd.username);
   pd.html->ErrorPage(errmsg);
   }
