@@ -152,6 +152,9 @@ class Language
 #define MSG_SHOWOPTIONS_APPEARANCE  107
 #define MSG_CONF_FILTERSDELETE      108
 #define MSG_INSERTSPAMFILTER        109
+#define MSG_CONFDELETEEVENT         110
+#define MSG_CONF_CLEARMAILBOX       111
+#define MSG_INSERTSPAMFILTER2       112
 
 //*******************************************************
 //ERR_ begin in 1000  
@@ -193,6 +196,7 @@ class Language
 #define ERR_SERVICE_INITIALIZING     1034
 #define ERR_CREAT_USERDATABASESDIR   1035
 #define ERR_FILTERALREADYEXISTS      1036
+#define ERR_ISOPEN_MAILBOX           1037
 
 //*******************************************************
 //ALT_ begin in 2000  
@@ -247,6 +251,8 @@ class Language
 #define ALT_DATABASES                2048
 #define ALT_NEXTRECORD               2049
 #define ALT_PREVRECORD               2050
+#define ALT_PREV                     2051
+#define ALT_NEXT                     2052
 
 //*******************************************************
 //TIT_ begin in 3000  
@@ -575,6 +581,38 @@ class Language
 #define L_SERVICEPW_INCORRECT        4288
 #define L_CALENDAR                   4289 
 #define L_CALENDAR_DESCRIPTION       4290
+#define L_CHANGE                     4291
+#define L_WEEK                       4292
+#define L_TODAY                      4293
+#define L_HOUR                       4294
+#define L_TITLE                      4295
+#define L_DESCRIPTION                4296
+#define L_STATUS                     4297
+#define L_STATUS_FINISHED            4298
+#define L_STATUS_OPEN                4299
+#define L_STATUS_DELAYED             4300
+#define L_PRIORITY                   4301
+#define L_PRIORITY_LOW               4302
+#define L_PRIORITY_CURRENT           4303
+#define L_PRIORITY_IMPORTANT         4304
+#define L_PRIORITY_VERYIMPORTANT     4305
+#define L_TYPE                       4306
+#define L_TYPE_CELEBRATION           4307
+#define L_TYPE_MEETING               4308
+#define L_TYPE_LAUNCH                4309
+#define L_TYPE_OTHER                 4310
+#define L_ADD                        4311
+#define L_YESTERDAY                  4312
+#define L_TOMORROW                   4313
+#define L_YEAR                       4314
+#define L_DAY                        4315
+#define L_LEX_SINCE                  4316
+#define L_INSERTSPAWNFILTER2         4317
+#define L_CLEARMAILBOX               4318
+#define L_CREATEFILTER               4319
+#define L_DOTLEARN                   4320
+#define L_DOTLEARN_DESCRIPTION       4321
+#define L_MODERATORS                 4322
 
 //*******************************************************
 //IMG_ begin in 5000  
@@ -592,6 +630,8 @@ class Language
 #define IMG_FLAG_UNSEARCHED          5010
 #define IMG_FLAG_COPIED              5011
 #define IMG_FLAG_UNCOPIED            5012
+#define IMG_LEFT_ARROW               5013
+#define IMG_RIGHT_ARROW              5014
 
 //*******************************************************
 //others begin in 10000  
