@@ -163,10 +163,10 @@ void Newsrc_lsub (MAILSTREAM *stream,char *pattern)
       if (c == ':') {           /* found a subscribed newsgroup? */
         *s = '\0';              /* yes, tie off name */
                                 /* report if match */
-        if (pmatch_full (name,pattern,'.')) mm_lsub (stream,'.',name,NIL);
+        if (pmatch_full ((unsigned char *)name,(unsigned char *)pattern,'.')) mm_lsub (stream,'.',name,NIL);
         else while (showuppers && (t = strrchr (lcl,'.'))) {
           *t = '\0';            /* tie off the name */
-          if (pmatch_full (name,pattern,'.'))
+          if (pmatch_full ((unsigned char *)name,(unsigned char *)pattern,'.'))
             mm_lsub (stream,'.',name,LATT_NOSELECT);
         }
       }
