@@ -5,6 +5,7 @@ SendMSG.cc
 #include "SendMSG.h"
 extern Language *L;
 extern STRINGDRIVER file_string;
+extern STRINGDRIVER postman_file_string;
 
 //For avoid a Microsoft Bug in Outlook XP
 //  http://www.washington.edu/pine/pine-info/2002.04/msg00042.html
@@ -244,7 +245,7 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
   smtpsocket->SetSock (sock);
   /*LEO LA LINEA DE BIENVENIDA*/
   /*-1 by the possible buffer overflow resulting from the linefeed added below. */
-  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;}
+  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
   sscanf (buffer, "%d %2000s", &cod, basura);
   if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
 
@@ -258,12 +259,12 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
     {                                
     snprintf (buffer, CMAXBUFFER, "HELO %s\n", localhost);
     }
-  if (smtpsocket->Puts (buffer) == -1) {return false;}
+  if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
 
   do
     {
     /*LEO LA LINEAS DEVUELTAS*/
-    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
     XS = XString (buffer);
     xstrncpy (stcod,  CMAXBUFFER, XS.substring (0, 3).cstr());
     xstrncpy (stsep,  CMAXBUFFER, XS.substring (3, 4).cstr());
@@ -291,10 +292,10 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
     /*ENVIO AUTH PLAIN*/
     snprintf (buffer, CMAXBUFFER, "auth plain %s\n", base64);
     //DEBUG ("--%s--", buffer);
-    if (smtpsocket->Puts (buffer) == -1) {return false;}
+    if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
 
     /*LEO LA LINEA DE AUTH PLAIN*/
-    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
     sscanf (buffer, "%d %2000s", &cod, basura);
     if (cod != 235) 
       {
@@ -321,10 +322,10 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
 
   /*ENVIO MAIL FROM*/
   snprintf (buffer, CMAXBUFFER, "MAIL FROM: %s@%s\n", user, MailDomain);
-  if (smtpsocket->Puts (buffer) == -1) {return false;}
+  if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
     
   /*LEO LA LINEA DE MAIL FROM*/
-  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
   sscanf (buffer, "%d %2000s", &cod, basura);
   if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
   
@@ -335,36 +336,36 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
   for (int k = 0; k < SLTO.Count(); ++k)
     {
     snprintf (buffer, CMAXBUFFER, "RCPT TO: %s\n", SLTO.getString(k).cstr());
-    if (smtpsocket->Puts (buffer) == -1) {return false;}
+    if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
     /*LEO LA LINEA DE RCPT*/
-    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
     sscanf (buffer, "%d %2000s", &cod, basura);
     if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
     }
   for (int h = 0; h < SLCC.Count(); ++h)
     {
     snprintf (buffer, CMAXBUFFER, "RCPT TO: %s\n", SLCC.getString(h).cstr());
-    if (smtpsocket->Puts (buffer) == -1) {return false;}
+    if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
     /*LEO LA LINEA DE RCPT*/
-    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
     sscanf (buffer, "%d %2000s", &cod, basura);
     if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
     }    
   for (int m = 0; m < SLBCC.Count(); ++m)
     {
     snprintf (buffer, CMAXBUFFER, "RCPT TO: %s\n", SLBCC.getString(m).cstr());
-    if (smtpsocket->Puts (buffer) == -1) {return false;}
+    if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
     /*LEO LA LINEA DE RCPT*/
-    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+    if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
     sscanf (buffer, "%d %2000s", &cod, basura);
     if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
     }    
           
   /*ENVIO DATA*/
   snprintf (buffer, CMAXBUFFER, "DATA\n");
-  if (smtpsocket->Puts (buffer) == -1) {return false;}
+  if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
   /*LEO LA LINEA DE DATA*/
-  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
   sscanf (buffer, "%d %2000s", &cod, basura);
   if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
   
@@ -552,7 +553,7 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
         
     sz = FileSize (fntmp);
     FR = fopen (fntmp, "r");
-    INIT (&stmsg, file_string, (void *)FR, sz);
+    INIT (&stmsg, postman_file_string, (void *)FR, sz);
     bo = cclient->appendMsg (SentMailBox, &stmsg);
     if (!bo)
       {      
@@ -560,7 +561,7 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
       if (bo) 
         {      
         *createdsentmailfolder = true;
-        INIT (&stmsg, file_string, (void *)FR, sz);
+        INIT (&stmsg, postman_file_string, (void *)FR, sz);
         bool bx;
         bx = cclient->appendMsg(SentMailBox, &stmsg);
         if (bx == false)
@@ -585,27 +586,27 @@ bool SendMSG::sendSMTP  (TBuffer errormsg, const char *sentmail, bool *createdse
       {
       if (strcmp (linea, ".\n") == 0) {xstrncpy (linea, MAXLENGTHLINE, " .\n");}
       if (strcmp (linea, ".\015\012") == 0) {xstrncpy (linea, MAXLENGTHLINE, " .\n");}        
-      if (smtpsocket->Puts (linea) == -1) {fclose (FR); DeleteFile (fntmp); return false;}    
+      if (smtpsocket->Puts (linea) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); fclose (FR); DeleteFile (fntmp); return false;}    
       }
     initStr (linea);
     }
   fclose (FR);
   
   snprintf (buffer, CMAXBUFFER, "\r\n.\r\n");
-  if (smtpsocket->Puts (buffer) == -1) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   
   /*LEO LA LINEA DE ACEPTACION DE DATOS*/
-  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   sscanf (buffer, "%d %2000s", &cod, basura);
-  if ((cod < 200) || (cod > 400)) {fclose (FR); DeleteFile (fntmp); return false;}
+  if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, buffer); DeleteFile (fntmp); return false;}
   
   /*ENVIO QUIT*/
   snprintf (buffer, CMAXBUFFER, "QUIT\n");
-  if (smtpsocket->Puts (buffer) == -1) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (smtpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   /*LEO LA LINEA DE QUIT*/
-  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (!smtpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   sscanf (buffer, "%d %2000s", &cod, basura);
-  if ((cod < 200) || (cod > 400)) {fclose (FR); DeleteFile (fntmp); return false;}
+  if ((cod < 200) || (cod > 400)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   
   DeleteFile (fntmp);
   //LOG ("--%s--", fntmp);
@@ -656,15 +657,15 @@ bool SendMSG::sendNNTP  (TBuffer errormsg, const char *sentmail, bool *createdse
   nntpsocket->SetSock (sock);
   /*LEO LA LINEA DE BIENVENIDA*/
   /*-1 by the possible buffer overflow resulting from the linefeed added below. */
-  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;}
+  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
   sscanf (buffer, "%d %2000s", &cod, basura);
   if (cod != 200) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
 
   /*ENVIO POST*/
   snprintf (buffer, CMAXBUFFER, "Post\n");
-  if (nntpsocket->Puts (buffer) == -1) {return false;}
+  if (nntpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;}
   /*LEO LA LINEA DEVUELTA*/
-  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {return false;} 
+  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); return false;} 
   sscanf (buffer, "%d %2000s", &cod, basura);
   if (cod != 340) {xstrncpy (errormsg, CMAXBUFFER, buffer); return false;}
   
@@ -849,7 +850,7 @@ bool SendMSG::sendNNTP  (TBuffer errormsg, const char *sentmail, bool *createdse
         
     sz = FileSize (fntmp);
     FR = fopen (fntmp, "r");
-    INIT (&stmsg, file_string, (void *)FR, sz);
+    INIT (&stmsg, postman_file_string, (void *)FR, sz);
     bo = cclient->appendMsg (SentMailBox, &stmsg);
     if (!bo)
       {      
@@ -857,7 +858,7 @@ bool SendMSG::sendNNTP  (TBuffer errormsg, const char *sentmail, bool *createdse
       if (bo) 
         {      
         *createdsentmailfolder = true;
-        INIT (&stmsg, file_string, (void *)FR, sz);
+        INIT (&stmsg, postman_file_string, (void *)FR, sz);
         bool bx;
         bx = cclient->appendMsg(SentMailBox, &stmsg);
         if (bx == false)
@@ -882,27 +883,27 @@ bool SendMSG::sendNNTP  (TBuffer errormsg, const char *sentmail, bool *createdse
       {
       if (strcmp (linea, ".\n") == 0) {xstrncpy (linea, MAXLENGTHLINE, " .\n");}
       if (strcmp (linea, ".\015\012") == 0) {xstrncpy (linea, MAXLENGTHLINE, " .\n");}        
-      if (nntpsocket->Puts (linea) == -1) {fclose (FR); DeleteFile (fntmp); return false;}    
+      if (nntpsocket->Puts (linea) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); fclose (FR); DeleteFile (fntmp); return false;}    
       }
     initStr (linea);
     }
   fclose (FR);
   
   snprintf (buffer, CMAXBUFFER, "\r\n.\r\n");
-  if (nntpsocket->Puts (buffer) == -1) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (nntpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   
   /*LEO LA LINEA DE ACEPTACION DE DATOS*/
-  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   sscanf (buffer, "%d %2000s", &cod, basura);
-  if (cod != 240) {xstrncpy (errormsg, CMAXBUFFER, buffer); fclose (FR); DeleteFile (fntmp); return false;}  
+  if (cod != 240) {xstrncpy (errormsg, CMAXBUFFER, buffer); DeleteFile (fntmp); return false;}  
   
   /*ENVIO QUIT*/
   snprintf (buffer, CMAXBUFFER, "QUIT\n");
-  if (nntpsocket->Puts (buffer) == -1) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (nntpsocket->Puts (buffer) == -1) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   /*LEO LA LINEA DE QUIT*/
-  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {fclose (FR); DeleteFile (fntmp); return false;}
+  if (!nntpsocket->Gets (buffer, sizeof(buffer) -1)) {xstrncpy (errormsg, CMAXBUFFER, "Socket data"); DeleteFile (fntmp); return false;}
   sscanf (buffer, "%d %2000s", &cod, basura);
-  if (cod != 205) {xstrncpy (errormsg, CMAXBUFFER, buffer); fclose (FR); DeleteFile (fntmp); return false;}  
+  if (cod != 205) {xstrncpy (errormsg, CMAXBUFFER, buffer); DeleteFile (fntmp); return false;}  
   
   DeleteFile (fntmp);
   //LOG ("--%s--", fntmp);
