@@ -86,6 +86,7 @@ bool DoService_Databases_BEGIN (TProgData *pd)
 //Entry point to service end
 bool DoService_Databases_END (TProgData *pd)
   {
+  if (Service_Databases_Initialized == false) {return true;}    
   Service_Databases_Initialized = false;  
   CDB->DBclose();
   delete CDB;
@@ -543,7 +544,7 @@ bool DoService_Databases_CMD (TProgData *pd)
         delete CDB; 
         CDB = NULL;         
         }
-      CDB = new ClientDB (dbfilename, pd->uo->getDatabasesDir(), false);
+      CDB = new ClientDB (dbfilename, pd->uo->getDatabasesDir(), false, true);
       if (CDB->DBopen () == false) 
         {
         html->ErrorPage(CDB->getErrorMsg());
