@@ -1043,7 +1043,7 @@ void HTMLPages::PrintFileBrowserDisplayPage (const char *stlang, const char *use
       
         //DATETIME
         WRITE ("<TD align=\"right\" bgcolor=\"%s\">\n", skin->getSkinAtribProp("COLOR_BGFILASMSGINDEX"));
-          Text (CFB->getFileDate (&CFB->FLAllFiles.elementAt(i).st_mtime, tmpbuf));
+          Text (CFB->getFileDate (&CFB->FLAllFiles.elementAt(i).stmtime, tmpbuf));
         EndTD();      
       EndTR();  
       }
@@ -1123,7 +1123,7 @@ void HTMLPages::PrintFileBrowserDisplayPage (const char *stlang, const char *use
       
         //FILEDATE
         WRITE ("<TD align=\"right\" bgcolor=\"%s\">\n", skin->getSkinAtribProp("COLOR_BGFILASMSGINDEX"));
-          Text (CFB->getFileDate (&CFB->FLAllFiles.elementAt(i).st_mtime, tmpbuf));
+          Text (CFB->getFileDate (&CFB->FLAllFiles.elementAt(i).stmtime, tmpbuf));
         EndTD();      
       EndTR();  
       }
