@@ -8,6 +8,7 @@ Service_Main.cc
 #include "Service_ForwardMail.h"
 #include "Service_FileBrowser.h"
 #include "Service_SecVirtual.h"
+#include "Service_Dotlearn.h"
 #include "Service_Databases.h"
 #include "Service_Finger.h"
 #include "Service_PersonalData.h"
@@ -186,6 +187,7 @@ bool doLogin (TProgData *pd)
       AddSuffixToIPName (xbuf);
       pd->uo->setImapServer (Conf->getString (xbuf, "imapserver", "imap.xx.xx", CMAXIPNAME));
       pd->uo->setImapPort   (Conf->getInt    (xbuf, "imapport", DEFIMAPPORT));
+      pd->uo->setAuthService   (Conf->getString    (xbuf, "auth_service", "cclient", CMAXBUFFER));            
       pd->uo->setMailDomain (Conf->getString (xbuf, "maildomain", "xx.xx", CMAXIPNAME));
       pd->uo->setSMTPServer (Conf->getString (xbuf, "smtpserver", "smtp.xx.xx", CMAXIPNAME));  
       pd->uo->setAuthSMTP   (Conf->getInt    (xbuf, "authsmtp", 0));
@@ -199,6 +201,8 @@ bool doLogin (TProgData *pd)
       pd->uo->setForwardsServer (Conf->getString (xbuf, "forwardsserver", "forwards.xx.xx", CMAXIPNAME));
       pd->uo->setSievePort    (Conf->getInt    (xbuf, "sieveport", DEFSIEVEPORT));
       pd->uo->setSieveServer  (Conf->getString (xbuf, "sieveserver", "sieve.xx.xx", CMAXIPNAME));
+      pd->uo->setLDAPPort    (Conf->getInt    (xbuf, "ldapport", DEFLDAPPORT));
+      pd->uo->setLDAPServer  (Conf->getString (xbuf, "ldapserver", "ldap.xx.xx", CMAXIPNAME));      
       pd->uo->setDeniedServices (Conf->getString (xbuf, "deniedservices", "", CMAXBUFFER));
       pd->uo->setTrueEmail ("");
       }
@@ -214,6 +218,7 @@ bool doLogin (TProgData *pd)
       AddSuffixToIPName (xbuf);
       pd->uo->setImapServer (xbuf);
       pd->uo->setImapPort   (aimapport);
+      pd->uo->setAuthService   (Conf->getString    (xbuf, "auth_service", "cclient", CMAXBUFFER));            
       pd->uo->setSMTPServer (asmtpserver);
       pd->uo->setAuthSMTP   (Conf->getInt    (xbuf, "authsmtp", 0));
       pd->uo->setMailDomain (amaildomain);
@@ -227,6 +232,8 @@ bool doLogin (TProgData *pd)
       pd->uo->setForwardsServer (Conf->getString (xbuf, "forwardsserver", "forwards.xx.xx", CMAXIPNAME));
       pd->uo->setSievePort    (Conf->getInt    (xbuf, "sieveport", DEFSIEVEPORT));
       pd->uo->setSieveServer  (Conf->getString (xbuf, "sieveserver", "sieve.xx.xx", CMAXIPNAME));
+      pd->uo->setLDAPPort    (Conf->getInt    (xbuf, "ldapport", DEFLDAPPORT));
+      pd->uo->setLDAPServer  (Conf->getString (xbuf, "ldapserver", "ldap.xx.xx", CMAXIPNAME));      
       pd->uo->setDeniedServices (Conf->getString (xbuf, "deniedservices", "", CMAXBUFFER));
       pd->uo->setTrueEmail (aliasemail);
       }        
@@ -239,6 +246,7 @@ bool doLogin (TProgData *pd)
     AddSuffixToIPName (xbuf);
     pd->uo->setImapServer (Conf->getString (xbuf, "imapserver", "imap.xx.xx", CMAXIPNAME));
     pd->uo->setImapPort   (Conf->getInt    (xbuf, "imapport", DEFIMAPPORT));
+    pd->uo->setAuthService   (Conf->getString    (xbuf, "auth_service", "cclient", CMAXBUFFER));            
     pd->uo->setMailDomain (Conf->getString (xbuf, "maildomain", "xx.xx", CMAXIPNAME));
     pd->uo->setSMTPServer (Conf->getString (xbuf, "smtpserver", "smtp.xx.xx", CMAXIPNAME));  
     pd->uo->setAuthSMTP   (Conf->getInt    (xbuf, "authsmtp", 0));
@@ -252,6 +260,8 @@ bool doLogin (TProgData *pd)
     pd->uo->setForwardsServer (Conf->getString (xbuf, "forwardsserver", "forwards.xx.xx", CMAXIPNAME));
     pd->uo->setSievePort    (Conf->getInt    (xbuf, "sieveport", DEFSIEVEPORT));
     pd->uo->setSieveServer  (Conf->getString (xbuf, "sieveserver", "sieve.xx.xx", CMAXIPNAME));
+    pd->uo->setLDAPPort    (Conf->getInt    (xbuf, "ldapport", DEFLDAPPORT));
+    pd->uo->setLDAPServer  (Conf->getString (xbuf, "ldapserver", "ldap.xx.xx", CMAXIPNAME));      
     pd->uo->setDeniedServices (Conf->getString (xbuf, "deniedservices", "", CMAXBUFFER));    
     pd->uo->setTrueEmail ("");
     }        
@@ -266,6 +276,7 @@ bool doLogin (TProgData *pd)
       {
       pd->uo->setImapServer (Conf->getString (xbuf, "imapserver", "imap.xx.xx", CMAXIPNAME));
       pd->uo->setImapPort   (Conf->getInt    (xbuf, "imapport", DEFIMAPPORT));
+      pd->uo->setAuthService   (Conf->getString    (xbuf, "auth_service", "cclient", CMAXBUFFER));            
       pd->uo->setMailDomain (Conf->getString (xbuf, "maildomain", "xx.xx", CMAXIPNAME));
       pd->uo->setSMTPServer (Conf->getString (xbuf, "smtpserver", pd->uo->getImapServer(), CMAXIPNAME));  
       pd->uo->setAuthSMTP   (Conf->getInt    (xbuf, "authsmtp", 0));
@@ -279,6 +290,8 @@ bool doLogin (TProgData *pd)
       pd->uo->setForwardsServer (Conf->getString (xbuf, "forwardsserver", "forwards.xx.xx", CMAXIPNAME));
       pd->uo->setSievePort    (Conf->getInt    (xbuf, "sieveport", DEFSIEVEPORT));
       pd->uo->setSieveServer  (Conf->getString (xbuf, "sieveserver", "sieve.xx.xx", CMAXIPNAME));
+      pd->uo->setLDAPPort    (Conf->getInt    (xbuf, "ldapport", DEFLDAPPORT));
+      pd->uo->setLDAPServer  (Conf->getString (xbuf, "ldapserver", "ldap.xx.xx", CMAXIPNAME));      
       pd->uo->setDeniedServices (Conf->getString (xbuf, "deniedservices", "", CMAXBUFFER));
       pd->uo->setTrueEmail ("");
       }
@@ -316,24 +329,38 @@ bool doLogin (TProgData *pd)
           {pd->uo->setMailDomain (pd->imapserver);}
         else                       
           {pd->uo->setMailDomain (Conf->getString ("*", "maildomain", "xx.xx", CMAXIPNAME));}                                                  
+        pd->uo->setAuthService   (Conf->getString    (xbuf, "auth_service", "cclient", CMAXBUFFER));            
         cclient->setMailboxPrefix (Conf->getString (xbuf, "mailboxprefix", "", CMAXBUFFER));
         pd->uo->setMailboxPrefix (Conf->getString (xbuf, "mailboxprefix", "", CMAXBUFFER));
         cclient->setPathToRemoteFolder (Conf->getString (xbuf, "remotepath", "", CMAXBUFFER));
         pd->uo->setSievePort    (Conf->getInt    (xbuf, "sieveport", DEFSIEVEPORT));
         pd->uo->setSieveServer  (Conf->getString (xbuf, "sieveserver", "sieve.xx.xx", CMAXIPNAME));
+        pd->uo->setLDAPPort    (Conf->getInt    (xbuf, "ldapport", DEFLDAPPORT));
+        pd->uo->setLDAPServer  (Conf->getString (xbuf, "ldapserver", "ldap.xx.xx", CMAXIPNAME));      
         pd->uo->setDeniedServices (Conf->getString (xbuf, "deniedservices", "", CMAXBUFFER));
         pd->uo->setTrueEmail ("");
         }
       }
     }   
-  sm_setproctitle (PROGNAME, true, "%s   (Before IMAPValidate)", pd->username);  
+  sm_setproctitle (PROGNAME, true, "%s   (Before Authentication)", pd->username);  
 
-  //DEBUG ("--%s--%d--%s--%s--",  pd->uo->getImapServer(), pd->uo->getImapPort(), pd->username, pd->password);
-  xstrncpy (pd->connid, CMAXBUFFER, make_session_id (pd->imapserver, tmp));
-  auth = new Authentication("login", pd->uo->getImapServer(), pd->uo->getImapPort(), pd->username, pd->password, pd->connid);
-  VALIDLOGIN = auth->doFirstAuthentication();
+  //DEBUG ("--%s--%d--", pd->uo->getAuthService(), pd->uo->getiAuthService());
+  if (pd->uo->getiAuthService() == iSERVICE_CCLIENT)
+     {
+     //DEBUG ("--%s--%d--%s--%s--",  pd->uo->getImapServer(), pd->uo->getImapPort(), pd->username, pd->password);
+     xstrncpy (pd->connid, CMAXBUFFER, make_session_id (pd->imapserver, tmp));
+     auth = new Authentication(iSERVICE_CCLIENT, pd->uo->getImapServer(), pd->uo->getImapPort(), pd->username, pd->password, pd->connid);
+     VALIDLOGIN = auth->doFirstAuthentication();
+     }
+   else
+     {//Default: ldap
+     //DEBUG ("--%s--%d--%s--%s--",  pd->uo->getLDAPServer(), pd->uo->getLDAPPort(), pd->username, pd->password);
+     xstrncpy (pd->connid, CMAXBUFFER, make_session_id (pd->imapserver, tmp));
+     auth = new Authentication(iSERVICE_LDAP, pd->uo->getLDAPServer(), pd->uo->getLDAPPort(), pd->username, pd->password, pd->connid);
+     VALIDLOGIN = auth->doFirstAuthentication();     
+     } 
 
-  sm_setproctitle (PROGNAME, true, "%s   (After IMAPValidate)", pd->username);  
+  sm_setproctitle (PROGNAME, true, "%s   (After Authentication)", pd->username);  
   cclient->setNNTPServer (pd->uo->getNNTPServer());
   return VALIDLOGIN;
   }
@@ -396,38 +423,49 @@ void PrintHomePage (TProgData *pd)
   pd->html->WRITE ("</TD>\n");   
  
     
-  //BUTTON MAIL  
-  pd->html->WRITE ("<TD align=\"left\">\n");
-  pd->html->WRITE ("<A HREF=\"%s/%s/mb_change/noop/%s/%s/%s/%d/%d/%d/\">", PATH_CGI, SERVICE_CCLIENT, pd->stlang, pd->username, pd->connid, validator, pageid, actualcmd);
-  pd->html->Image (GetService_Cclient_ICO_URL(), GetService_Cclient_ICO_ALT(), skin->getISize());
-  unread_msgs = cclient->getMsgsUnreadIMAPINBOX ();
-  pd->html->WRITE ("<FONT face=\"%s\" SIZE=\"-1\"><B>%s</B></A>", skin->getSkinAtribProp("FONT_TABLE"), GetService_Cclient_NAME());
-  switch (unread_msgs)
+  if (isAllowedService (pd->uo->SLAllowedServices, pd->uo->getDeniedServices(), -1, "cclient"))
     {
-    case -1: /*ERROR*/ 
-             break;
-    case 0:  pd->html->WRITE ("  <FONT SIZE=\"-1\">(%s)</FONT>\n", L->get(MSG_NEWMSGS_0));
-             break;
-    case 1:  pd->html->WRITE ("  <FONT SIZE=\"-1\">(%s)</FONT>\n", L->get(MSG_NEWMSGS_1));
-             break;
-    default: xsnprintf (tmp, CMAXBUFFER, L->get(MSG_NEWMSGS_n), unread_msgs);
-             pd->html->WRITE ("  <FONT SIZE=\"-1\">(%s)</FONT>\n", tmp);
-             break;                
-    }
-  pd->html->WRITE ("</FONT></TD>\n"); 
-  pd->html->WRITE ("</TR>\n");   
+    //BUTTON MAIL  
+    pd->html->WRITE ("<TD align=\"left\">\n");
+    pd->html->WRITE ("<A HREF=\"%s/%s/mb_change/noop/%s/%s/%s/%d/%d/%d/\">", PATH_CGI, SERVICE_CCLIENT, pd->stlang, pd->username, pd->connid, validator, pageid, actualcmd);
+    pd->html->Image (GetService_Cclient_ICO_URL(), GetService_Cclient_ICO_ALT(), skin->getISize());
+    unread_msgs = cclient->getMsgsUnreadIMAPINBOX ();
 
-  //BUTTON OPEN NEWS
+    if (unread_msgs == -1) 
+      {
+      //Possible I am validating with other than imap service. I need connect to imap for retrieve unread msgs.
+      DoService_Cclient_BEGIN (pd); 
+      unread_msgs = cclient->getMsgsUnreadIMAPINBOX ();
+      }
+
+    pd->html->WRITE ("<FONT face=\"%s\" SIZE=\"-1\"><B>%s</B></A>", skin->getSkinAtribProp("FONT_TABLE"), GetService_Cclient_NAME());
+    switch (unread_msgs)
+      {
+      case -1: /*ERROR*/ 
+               break;
+      case 0:  pd->html->WRITE ("  <FONT SIZE=\"-1\">(%s)</FONT>\n", L->get(MSG_NEWMSGS_0));
+               break;
+      case 1:  pd->html->WRITE ("  <FONT SIZE=\"-1\">(%s)</FONT>\n", L->get(MSG_NEWMSGS_1));
+               break;
+      default: xsnprintf (tmp, CMAXBUFFER, L->get(MSG_NEWMSGS_n), unread_msgs);
+               pd->html->WRITE ("  <FONT SIZE=\"-1\">(%s)</FONT>\n", tmp);
+               break;                
+      }
+    pd->html->WRITE ("</FONT></TD>\n"); 
+    pd->html->WRITE ("</TR>\n");   
+    }
+    
   if (isAllowedService (pd->uo->SLAllowedServices, pd->uo->getDeniedServices(), -1, "nntp"))
     {
+    //BUTTON OPEN SUBSCRIBED NEWS
     pd->html->WRITE ("<TR>\n");                          
     pd->html->WRITE ("<TD align=\"left\">\n");    
-    pd->html->WRITE ("<A HREF=\"%s/%s/mb_change/noop/%s/%s/%s/%d/%d/%d/:%s/\">", PATH_CGI, SERVICE_CCLIENT, pd->stlang, pd->username, pd->connid, validator, pageid, actualcmd, DEFAULTBEGINNNTPGROUP);
+    pd->html->WRITE ("<A HREF=\"%s/%s/nw_subscribed/noop/%s/%s/%s/%d/%d/%d/:%s/\">", PATH_CGI, SERVICE_CCLIENT, pd->stlang, pd->username, pd->connid, validator, pageid, actualcmd, DEFAULTBEGINNNTPGROUP);
     pd->html->Image (skin->getI(L_NNTP), L->get(ALT_NNTP), skin->getISize());
     pd->html->WRITE ("<FONT face=\"%s\" SIZE=\"-1\"><B>%s</B></FONT>\n", skin->getSkinAtribProp("FONT_TABLE"),  L->get(L_NNTP));
     pd->html->WRITE ("</A>\n");
     pd->html->WRITE ("</TD>\n");    
-    pd->html->WRITE ("</TR>\n");
+    pd->html->WRITE ("</TR>\n");    
     }
   
   if (isAllowedService (pd->uo->SLAllowedServices, pd->uo->getDeniedServices(), iSERVICE_POPPASS, NULL))
@@ -486,6 +524,19 @@ void PrintHomePage (TProgData *pd)
     pd->html->WRITE ("</TR>\n");
     }                         
     
+  if (isAllowedService (pd->uo->SLAllowedServices, pd->uo->getDeniedServices(), iSERVICE_DOTLEARN, NULL))
+    {
+    //BUTTON SECVIRTUAL
+    pd->html->WRITE ("<TR>\n");
+    pd->html->WRITE ("<TD align=\"left\">\n");
+    pd->html->WRITE ("<A HREF=\"%s/%s/goto/noop/%s/%s/%s/%d/%d/%d/\">", PATH_CGI, SERVICE_DOTLEARN, pd->stlang, pd->username, pd->connid, validator, pageid, actualcmd);
+    pd->html->Image (GetService_Dotlearn_ICO_URL(),  GetService_Dotlearn_ICO_ALT(), skin->getISize());
+    pd->html->WRITE ("<FONT face=\"%s\" SIZE=\"-1\"><B>%s</B></FONT>\n", skin->getSkinAtribProp("FONT_TABLE"), GetService_Dotlearn_NAME());
+    pd->html->WRITE ("</A>\n");
+    pd->html->WRITE ("</TD>\n");    
+    pd->html->WRITE ("</TR>\n");
+    }                             
+    
   if (isAllowedService (pd->uo->SLAllowedServices, pd->uo->getDeniedServices(), iSERVICE_USERACCOUNTS, NULL))
     {
     //BUTTON USERACCOUNTS
@@ -536,6 +587,19 @@ void PrintHomePage (TProgData *pd)
     pd->html->WRITE ("</A>\n");
     pd->html->WRITE ("</TD>\n");    
     pd->html->WRITE ("</TR>\n");
+    if (pd->uo->getShowCalendarTodayEvents() == true)
+      {
+      TBuffer events_warning;
+      DoService_Calendar_BEGIN (pd);                  
+      if (getWarningToday (events_warning) > 0)          
+        {
+        pd->html->WRITE ("<TR>\n");               
+        pd->html->WRITE ("<TD align=\"center\">\n");               
+        pd->html->WRITE ("<FONT SIZE=1 COLOR=#FF0000>%s</FONT>", events_warning);
+        pd->html->WRITE ("</TD>\n");    
+        pd->html->WRITE ("</TR>\n");
+        }
+      }
     }            
     
   if (isAllowedService (pd->uo->SLAllowedServices, pd->uo->getDeniedServices(), iSERVICE_CONFIG, NULL))
