@@ -216,6 +216,7 @@ bool DoService_Sieve_CMD (TProgData *pd)
   else if ((pd->cmd == CMD_SIEVE_FILTERS_DO) && (cgienv_ExistsVar (pd->envfile, "filters_up") == true)) {pd->cmd = CMD_SIEVE_FILTERS_UP;}    
   else if ((pd->cmd == CMD_SIEVE_FILTERS_DO) && (cgienv_ExistsVar (pd->envfile, "filters_down") == true)) {pd->cmd = CMD_SIEVE_FILTERS_DOWN;}  
   else if ((pd->cmd == CMD_SIEVE_FILTERS_DO) && (cgienv_ExistsVar (pd->envfile, "filters_predefspam") == true)) {pd->cmd = CMD_SIEVE_FILTERS_PREDEFSPAM;}  
+  else if ((pd->cmd == CMD_SIEVE_FILTERS_DO) && (cgienv_ExistsVar (pd->envfile, "filters_predefspam2") == true)) {pd->cmd = CMD_SIEVE_FILTERS_PREDEFSPAM2;}  
   else if ((pd->cmd == CMD_SIEVE_VACATIONS_DO) && (cgienv_ExistsVar (pd->envfile, "vacations_save") == true)) {pd->cmd = CMD_SIEVE_VACATIONS_SAVE;}
   else if ((pd->cmd == CMD_SIEVE_VACATIONS_DO) && (cgienv_ExistsVar (pd->envfile, "vacations_cancel") == true)) {pd->cmd = CMD_SIEVE_VACATIONS_CANCEL;}    
   cmd = pd->cmd;
@@ -260,9 +261,11 @@ bool DoService_Sieve_CMD (TProgData *pd)
       break;   
       }      
     case (CMD_SIEVE_FILTERS_PREDEFSPAM):
+    case (CMD_SIEVE_FILTERS_PREDEFSPAM2):    
       {
       bool b;      
-      if (CTS->isThereFilter(PREDEF_ANTISPAMFILTERNAME) == true)
+      if (((CTS->isThereFilter(PREDEF_ANTISPAMFILTERNAME) == true) && (pd->cmd == CMD_SIEVE_FILTERS_PREDEFSPAM)) ||
+          ((CTS->isThereFilter(PREDEF_ANTISPAMFILTERNAME2) == true) && (pd->cmd == CMD_SIEVE_FILTERS_PREDEFSPAM2)))
         {
         pd->html->ErrorPage(L->get(ERR_FILTERALREADYEXISTS));
         } 
@@ -271,7 +274,14 @@ bool DoService_Sieve_CMD (TProgData *pd)
         TBuffer SpamMailBox, abuf;
         xstrncpy (SpamMailBox, CMAXBUFFER, cclient->expandMailboxName (SPAMMAILBOX, abuf));
         b = cclient->createMailbox (SpamMailBox);          
-        b = CTS->saveAntiSpamFilterToFile (pd->envfile, SpamMailBox);
+        if (pd->cmd == CMD_SIEVE_FILTERS_PREDEFSPAM)
+          {        
+          b = CTS->saveAntiSpamFilterToFile (pd->envfile, SpamMailBox);
+          }
+        else if (pd->cmd == CMD_SIEVE_FILTERS_PREDEFSPAM2)
+          {
+          b = CTS->saveAntiSpamFilterToFile2 (pd->envfile, SpamMailBox);          
+          }
         if (b == false)
           {
           pd->html->ErrorPage(CTS->getErrorMsg());                
@@ -333,7 +343,16 @@ bool DoService_Sieve_CMD (TProgData *pd)
           }
         else
           {
-          html->PrintSieveFiltersShow (pd);
+          b = CTS->saveSieveNetwork();
+          if (b == false)
+            {
+            pd->html->ErrorPage(CTS->getErrorMsg());
+            }
+          else
+            {
+            pd->uo->setStatusLine (L->get(MSG_SAVEOPTIONS), BLUE);
+            html->PrintSieveFiltersShow (pd);
+            }
           }
         }          
       break;   
@@ -357,7 +376,16 @@ bool DoService_Sieve_CMD (TProgData *pd)
           }
         else
           {
-          html->PrintSieveFiltersShow (pd);
+          b = CTS->saveSieveNetwork();
+          if (b == false)
+            {
+            pd->html->ErrorPage(CTS->getErrorMsg());
+            }
+          else
+            {
+            pd->uo->setStatusLine (L->get(MSG_SAVEOPTIONS), BLUE);
+            html->PrintSieveFiltersShow (pd);
+            }
           }
         }        
       break;   
@@ -408,7 +436,16 @@ bool DoService_Sieve_CMD (TProgData *pd)
           }
         else
           {
-          html->PrintSieveFiltersShow (pd);
+          b = CTS->saveSieveNetwork();
+          if (b == false)
+            {
+            pd->html->ErrorPage(CTS->getErrorMsg());
+            }
+          else
+            {
+            pd->uo->setStatusLine (L->get(MSG_SAVEOPTIONS), BLUE);
+            html->PrintSieveFiltersShow (pd);
+            }
           }
         }        
       delete SLMulti;  
@@ -492,7 +529,10 @@ void HTMLPages::PrintSieveFiltersShow (TProgData *pd)
   FormButton ("filters_create",     L->get(L_CREATE));
   FormButton ("filters_edit",       L->get(L_EDIT));
   if (FLAllFilters.Count() > 0) {FormButton ("filters_confdelete", L->get(L_DELETE));}
+  BR();
+  Label (L->get(L_CREATEFILTER));
   WRITE ("<INPUT TYPE=SUBMIT NAME=\"%s\" VALUE=\"%s\" onClick=\"return confirm('%s')\">\n", "filters_predefspam",  L->get(L_INSERTSPAWNFILTER), L->get(MSG_INSERTSPAMFILTER));
+  WRITE ("<INPUT TYPE=SUBMIT NAME=\"%s\" VALUE=\"%s\" onClick=\"return confirm('%s')\">\n", "filters_predefspam2",  L->get(L_INSERTSPAWNFILTER2), L->get(MSG_INSERTSPAMFILTER2));  
   BR();  
 
   WRITE ("<TABLE>\n");  
