@@ -17,6 +17,8 @@ Services.cc
 //config       --> Service for handle Postman Configuration
 //sieve        --> Service for mail: filters, vacation.
 //calendar     --> Service for calendar
+//dotlearn     --> Service for students and teachers: frontend to elearning  (University of Valencia)
+//ldap         --> Service for LDAP actions: authenticate, ...
 
 int TranslateService (const char *stservice)
   {
@@ -31,12 +33,14 @@ int TranslateService (const char *stservice)
   if (strcmp (uplinea, "FINGER")== 0)             {return iSERVICE_FINGER;}    
   if (strcmp (uplinea, "FILEBROWSER")== 0)        {return iSERVICE_FILEBROWSER;}    
   if (strcmp (uplinea, "FORWARDMAIL")== 0)        {return iSERVICE_FORWARDMAIL;}      
-  if (strcmp (uplinea, "SECVIRTUAL")== 0)         {return iSERVICE_SECVIRTUAL;}        
+  if (strcmp (uplinea, "SECVIRTUAL")== 0)         {return iSERVICE_SECVIRTUAL;}          
   if (strcmp (uplinea, "PERSONALDATA")== 0)       {return iSERVICE_PERSONALDATA;}      
   if (strcmp (uplinea, "USERACCOUNTS")== 0)       {return iSERVICE_USERACCOUNTS;}              
   if (strcmp (uplinea, "CONFIG")== 0)             {return iSERVICE_CONFIG;}                
   if (strcmp (uplinea, "SIEVE")== 0)              {return iSERVICE_SIEVE;}                  
-  if (strcmp (uplinea, "CALENDAR")== 0)           {return iSERVICE_CALENDAR;}                    
+  if (strcmp (uplinea, "CALENDAR")== 0)           {return iSERVICE_CALENDAR;}          
+  if (strcmp (uplinea, "DOTLEARN")== 0)           {return iSERVICE_DOTLEARN;}
+  if (strcmp (uplinea, "LDAP")== 0)               {return iSERVICE_LDAP;}
   return iSERVICE_INVALID;                
   }
 
@@ -57,6 +61,8 @@ const char *TranslateServiceR (int service)
     case iSERVICE_CONFIG:        return SERVICE_CONFIG; break;             
     case iSERVICE_SIEVE:         return SERVICE_SIEVE; break;                 
     case iSERVICE_CALENDAR:      return SERVICE_CALENDAR; break;                     
+    case iSERVICE_DOTLEARN:      return SERVICE_DOTLEARN; break; 
+    case iSERVICE_LDAP:          return SERVICE_LDAP; break;     
     default:                     return SERVICE_MAIN; break;
     }
   }
@@ -93,6 +99,7 @@ int TranslateCmd (int service, const char *stcmd)
       if (strcmp (uplinea, "MB_CHANGE")      == 0)    {return CMD_CCLIENT_MB_CHANGE;}
       if (strcmp (uplinea, "MB_CREATE")      == 0)    {return CMD_CCLIENT_MB_CREATE;}
       if (strcmp (uplinea, "MB_DELETE")      == 0)    {return CMD_CCLIENT_MB_DELETE;}
+      if (strcmp (uplinea, "MB_CLEAR")       == 0)    {return CMD_CCLIENT_MB_CLEAR;}      
       if (strcmp (uplinea, "MB_RENAME")      == 0)    {return CMD_CCLIENT_MB_RENAME;}
       if (strcmp (uplinea, "MB_EXPUNGE")     == 0)    {return CMD_CCLIENT_MB_EXPUNGE;}
       if (strcmp (uplinea, "MB_DUMP")        == 0)    {return CMD_CCLIENT_MB_DUMP;}  
@@ -146,6 +153,7 @@ int TranslateCmd (int service, const char *stcmd)
       if (strcmp (uplinea, "MG_FG_UNSEARCHED")== 0)   {return CMD_CCLIENT_MG_FG_UNSEARCHED;}          
       if (strcmp (uplinea, "BD_UUDECODE")== 0)        {return CMD_CCLIENT_BD_UUDECODE;}        
       if (strcmp (uplinea, "NW_LIST_DUMP")== 0)       {return CMD_CCLIENT_NW_LIST_DUMP;}
+      if (strcmp (uplinea, "NW_SUBSCRIBED")== 0)      {return CMD_CCLIENT_NW_SUBSCRIBED;}      
       return CMD_SPECIAL_INVALID;
       break;
     case iSERVICE_POPPASS: 
@@ -256,6 +264,7 @@ int TranslateCmd (int service, const char *stcmd)
       if (strcmp (uplinea, "FILTERS_DOWN")== 0)             {return CMD_SIEVE_FILTERS_DOWN;}            
       if (strcmp (uplinea, "FILTERS_CONFDELETE")== 0)       {return CMD_SIEVE_FILTERS_CONFDELETE;}                  
       if (strcmp (uplinea, "FILTERS_PREDEFSPAM")== 0)       {return CMD_SIEVE_FILTERS_PREDEFSPAM;}                        
+      if (strcmp (uplinea, "FILTERS_PREDEFSPAM2")== 0)      {return CMD_SIEVE_FILTERS_PREDEFSPAM2;}                              
       if (strcmp (uplinea, "VACATIONS_SHOW")== 0)           {return CMD_SIEVE_VACATIONS_SHOW;}            
       if (strcmp (uplinea, "VACATIONS_DO")== 0)             {return CMD_SIEVE_VACATIONS_DO;}            
       if (strcmp (uplinea, "VACATIONS_SAVE")== 0)           {return CMD_SIEVE_VACATIONS_SAVE;}            
@@ -267,9 +276,22 @@ int TranslateCmd (int service, const char *stcmd)
       if (strcmp (uplinea, "MONTH_SHOW")== 0)               {return CMD_CALENDAR_MONTH_SHOW;}
       if (strcmp (uplinea, "WEEK_SHOW")== 0)                {return CMD_CALENDAR_WEEK_SHOW;}
       if (strcmp (uplinea, "DAY_SHOW")== 0)                 {return CMD_CALENDAR_DAY_SHOW;}
-      if (strcmp (uplinea, "EVENTS_SHOW")== 0)              {return CMD_CALENDAR_EVENTS_SHOW;}
+      if (strcmp (uplinea, "TODAY")== 0)                    {return CMD_CALENDAR_TODAY;}
+      if (strcmp (uplinea, "EVENTS_CREATE")== 0)            {return CMD_CALENDAR_EVENTS_CREATE;}            
+      if (strcmp (uplinea, "EVENTS_ADD")== 0)               {return CMD_CALENDAR_EVENTS_ADD;}      
+      if (strcmp (uplinea, "EVENTS_MODIFY")== 0)            {return CMD_CALENDAR_EVENTS_MODIFY;}            
+      if (strcmp (uplinea, "EVENTS_DELETE")== 0)            {return CMD_CALENDAR_EVENTS_DELETE;}                  
+      if (strcmp (uplinea, "TOMORROW")== 0)                 {return CMD_CALENDAR_TOMORROW;}
+      if (strcmp (uplinea, "YESTERDAY")== 0)                {return CMD_CALENDAR_YESTERDAY;}      
       return CMD_SPECIAL_INVALID;
       break;      
+    case iSERVICE_DOTLEARN:
+      if (strcmp (uplinea, "GOTO")== 0)                     {return CMD_DOTLEARN_GOTO;}
+      return CMD_SPECIAL_INVALID;
+      break;               
+    case iSERVICE_LDAP:       
+      return CMD_SPECIAL_INVALID;
+      break;                   
     default:
       return CMD_SPECIAL_INVALID;
       break;
@@ -316,6 +338,7 @@ bool is_CMD_ALLOWED_ACTION (int ACTION, int service, int cmd)
         case iSERVICE_CONFIG:         {return false; break;}        
         case iSERVICE_SIEVE:          {return false; break;}                
         case iSERVICE_CALENDAR:       {return false; break;}                        
+        case iSERVICE_DOTLEARN:       {return false; break;}
         default:                      {return false; break;}                  
         }
       break;
@@ -357,6 +380,7 @@ int getiServiceFromCmd (int cmd)
     case CMD_CCLIENT_MB_CHANGE:
     case CMD_CCLIENT_MB_CREATE:
     case CMD_CCLIENT_MB_DELETE:
+    case CMD_CCLIENT_MB_CLEAR:
     case CMD_CCLIENT_MB_RENAME:
     case CMD_CCLIENT_MB_EXPUNGE:
     case CMD_CCLIENT_MB_DUMP:  
@@ -501,6 +525,11 @@ int getiServiceFromCmd (int cmd)
       return iSERVICE_USERACCOUNTS;
       break;                            
       }
+    case CMD_DOTLEARN_GOTO:
+      {
+      return iSERVICE_DOTLEARN;
+      break; 
+      }               
     case CMD_CONFIG:
     case CMD_CONFIG_CANCEL:
     case CMD_CONFIG_CCLIENT:      
@@ -526,6 +555,7 @@ int getiServiceFromCmd (int cmd)
     case CMD_SIEVE_FILTERS_DOWN:    
     case CMD_SIEVE_FILTERS_CONFDELETE:
     case CMD_SIEVE_FILTERS_PREDEFSPAM:
+    case CMD_SIEVE_FILTERS_PREDEFSPAM2:    
     case CMD_SIEVE_VACATIONS_SHOW:
     case CMD_SIEVE_VACATIONS_DO:            
     case CMD_SIEVE_VACATIONS_SAVE:  
@@ -538,7 +568,13 @@ int getiServiceFromCmd (int cmd)
     case CMD_CALENDAR_MONTH_SHOW:            
     case CMD_CALENDAR_WEEK_SHOW:                
     case CMD_CALENDAR_DAY_SHOW:            
-    case CMD_CALENDAR_EVENTS_SHOW:            
+    case CMD_CALENDAR_TODAY:
+    case CMD_CALENDAR_TOMORROW:    
+    case CMD_CALENDAR_YESTERDAY:    
+    case CMD_CALENDAR_EVENTS_CREATE:                    
+    case CMD_CALENDAR_EVENTS_ADD:                
+    case CMD_CALENDAR_EVENTS_MODIFY:                    
+    case CMD_CALENDAR_EVENTS_DELETE:                        
       {
       return iSERVICE_CALENDAR;
       break;
