@@ -462,6 +462,8 @@ const char *Skin::getImageNoLang (int WHAT)
     case IMG_FLAG_UNSEARCHED: xsnprintf (abuff, CMAXBUFFER, "%s/%s/flag_unsearched.gif", PATH_IMAGENS, theiconset); break;
     case IMG_FLAG_COPIED:     xsnprintf (abuff, CMAXBUFFER, "%s/%s/flag_copied.gif", PATH_IMAGENS, theiconset); break;
     case IMG_FLAG_UNCOPIED:   xsnprintf (abuff, CMAXBUFFER, "%s/%s/flag_uncopied.gif", PATH_IMAGENS, theiconset); break;
+    case IMG_LEFT_ARROW:      xsnprintf (abuff, CMAXBUFFER, "%s/%s/arrow_left.gif", PATH_IMAGENS, theiconset); break;
+    case IMG_RIGHT_ARROW:     xsnprintf (abuff, CMAXBUFFER, "%s/%s/arrow_right.gif", PATH_IMAGENS, theiconset); break;        
     case L_LOGOUT:            xsnprintf (abuff, CMAXBUFFER, "%s/%s/logout.gif", PATH_IMAGENS, theiconset); break;
     case L_NEXTPAGE_ACT:      xsnprintf (abuff, CMAXBUFFER, "%s/%s/nextpage.gif", PATH_IMAGENS, theiconset); break;
     case L_NEXTPAGE_INA:      xsnprintf (abuff, CMAXBUFFER, "%s/%s/nextpage_ina.gif", PATH_IMAGENS, theiconset); break;
@@ -532,6 +534,7 @@ const char *Skin::getImageNoLang (int WHAT)
     case LANG_SPANISH:        xsnprintf (abuff, CMAXBUFFER, "%s/%s/spa.gif", PATH_IMAGENS, theiconset); break;    
     case LANG_CATALA:         xsnprintf (abuff, CMAXBUFFER, "%s/%s/val.gif", PATH_IMAGENS, theiconset); break;    
     case LANG_EUSKERA:        xsnprintf (abuff, CMAXBUFFER, "%s/%s/unknown.gif", PATH_IMAGENS, theiconset); break;
+    case L_DOTLEARN:          xsnprintf (abuff, CMAXBUFFER, "%s/%s/blackboard.gif", PATH_IMAGENS, theiconset); break;
     default:                  xsnprintf (abuff, CMAXBUFFER, "%s/%s/unknown.gif", PATH_IMAGENS, theiconset); break;
     }
   return abuff;          
