@@ -13,6 +13,7 @@ UserOptions::UserOptions (const char *abasepath, const char *auser, const char *
   validator = 0;
   WorkingWithCookies = false;
   UseJavaScript = true;
+  ShowCalendarTodayEvents = true;
   ConfirmPurge = DEFOPT_CONFIRMPURGE;
   ConfirmLogout = DEFOPT_CONFIRMLOGOUT;
   timeout = DEFTIMEOUT;
@@ -45,6 +46,7 @@ UserOptions::UserOptions (const char *abasepath, const char *auser, const char *
   initStr (POPPASSSERVER);
   initStr (FORWARDSSERVER);
   initStr (SIEVESERVER);
+  initStr (LDAPSERVER);
   pageid = -1;
   lastcmd = -1;
   SentmailName = DEFOPT_SENTMAILBOX;
@@ -108,7 +110,23 @@ const char *UserOptions::getMailDomain (void)
   {
   return MAILDOMAIN;
   }      
-    
+   
+void UserOptions::setAuthService (const char *aservice)
+  {
+  xstrncpy (AUTHSERVICE, CMAXBUFFER, aservice);
+  iAUTHSERVICE = TranslateService (AUTHSERVICE);
+  }
+  
+const char *UserOptions::getAuthService (void)
+  {
+  return AUTHSERVICE;
+  }
+        
+int UserOptions::getiAuthService (void)
+  {
+  return iAUTHSERVICE;
+  }
+ 
 void UserOptions::setAuthSMTP (int value)
   {
   AuthSMTP = value;
@@ -243,7 +261,26 @@ const char *UserOptions::getForwardsServer (void)
   {
   return FORWARDSSERVER;
   }    
+
+void UserOptions::setLDAPServer (const char *aldapserver)
+  {
+  xstrncpy (LDAPSERVER, CMAXIPNAME, aldapserver);
+  }
   
+const char *UserOptions::getLDAPServer (void)
+  {
+  return LDAPSERVER;
+  }    
+
+void UserOptions::setLDAPPort (int aldapport)
+  {
+  LDAPPORT = aldapport;
+  }
+int UserOptions::getLDAPPort (void)
+  {
+  return LDAPPORT;
+  }  
+
 void UserOptions::setForwardsPort (int aforwardsport)
   {
   FORWARDSPORT = aforwardsport;
@@ -320,6 +357,11 @@ const char *UserOptions::getUsername (void)
   return user.cstr();
   }  
 
+const char *UserOptions::getUserDir (void)
+  {
+  return userdir.cstr();
+  }  
+
 const char *UserOptions::getAttachDir (void)
   {
   return userattdir.cstr();
@@ -439,6 +481,16 @@ void UserOptions::setDisplayPersonalInfo (bool value)
   DisplayPersonalInfo = value;
   }  
   
+bool UserOptions::getShowCalendarTodayEvents (void)
+  {
+  return ShowCalendarTodayEvents;
+  }
+  
+void UserOptions::setShowCalendarTodayEvents (bool value)
+  {
+  ShowCalendarTodayEvents = value;
+  }    
+  
 bool UserOptions::getSaveMsgSentMail (void)
   {
   return SaveMsgSentMail;
@@ -852,7 +904,68 @@ const char *UserOptions::getfnSavedMsg (void)
     return fnsavednntpmsg.cstr();
     }
   }
+    
+const char *UserOptions::getSentMailName (void)
+  {
+  if (SentmailName.cstr() == NULL) return DEFOPT_SENTMAILBOX;
+  return SentmailName.cstr();
+  }
   
+void UserOptions::setSentMailName (const char *smname)
+  {
+  if ((smname == NULL) || (strcmp (smname, "") == 0)) return;
+  SentmailName = smname;
+  }
+
+bool UserOptions::getConfirmPurge (void)
+  {
+  return ConfirmPurge;
+  }
+  
+void UserOptions::setConfirmPurge (bool b)
+  {
+  ConfirmPurge = b;
+  }
+  
+bool UserOptions::getConfirmLogout (void)
+  {
+  return ConfirmLogout;  
+  }
+  
+void UserOptions::setConfirmLogout (bool b)
+  {
+  ConfirmLogout = b;
+  }
+
+void UserOptions::setLastService (int value)
+  {
+  LastService = value;
+  }
+  
+int UserOptions::getLastService (void)
+  {
+  return LastService;
+  }  
+   
+void UserOptions::setTimeout (int value)
+  {
+  timeout = value;
+  }
+  
+int UserOptions::getTimeout (void)
+  {
+  return timeout;
+  }        
+
+void UserOptions::setMountPoints (const char *amount_points)
+  {
+  xstrncpy (mount_points, CMAXBUFFER, amount_points);
+  }                                                    
+  
+const char *UserOptions::getMountPoints (void)
+  {
+  return mount_points;
+  }                                                      
 void UserOptions::setLastCmd (int value)
   {
   lastcmd = value;
@@ -899,7 +1012,7 @@ int UserOptions::getPageId (void)
 
 void UserOptions::addLastStringCmd (int cmd, const char *stcmd)
   { 
-  if (cmd != CMD_SPECIAL_CHECK_COOKIE)
+  if (cmd != CMD_SPECIAL_CHECK_COOKIE) 
     {
     //DEBUG ("anyadida=--%s--", stcmd);                            
     PilaCmds.Add(stcmd); 
@@ -938,6 +1051,7 @@ const char *UserOptions::getLastStringCmd (int cmdactual, const char *lang, cons
       sscanf (linea, "%s %d %d %d %s %s %d %s %s %s %s %s %s %s", 
                      aconnid, &otropageid, &avalidator, &alastcmd, stlang, 
                      ipclient, &aservice, stcmd, stsubcmd, tmpfile, parm1, parm2, parm3, parm4);
+      //DEBUG ("%s %s %s %s", parm1, parm2, parm3, parm4);
       sscanf (linea, "%s %d %d %d %s %s %d %s %s %s %[^]]s",      
                      aconnid, &otropageid, &avalidator, &alastcmd, stlang, 
                      ipclient, &aservice, stcmd, stsubcmd, tmpfile, allparms);
@@ -968,6 +1082,7 @@ const char *UserOptions::getLastStringCmd (int cmdactual, const char *lang, cons
           (cmd == CMD_CCLIENT_MG_DELDISPLAY)||          
           (cmd == CMD_SIEVE_FILTERS_DO)     || (cmd == CMD_SIEVE_FILTERS_CANCEL)  || (cmd == CMD_SIEVE_FILTERS_SAVE)   || (cmd == CMD_SIEVE_FILTERS_EDIT)         || 
           (cmd == CMD_SIEVE_VACATIONS_DO)   || (cmd == CMD_SIEVE_VACATIONS_CANCEL)|| (cmd == CMD_SIEVE_VACATIONS_SAVE) || 
+          (cmd == CMD_CALENDAR_EVENTS_CREATE)   || (cmd == CMD_CALENDAR_EVENTS_ADD) || (cmd == CMD_CALENDAR_EVENTS_DELETE)   || (cmd == CMD_CALENDAR_EVENTS_MODIFY) ||
           (cmd == cmdcomodin)               || (cmd == cmdcomodin2) ||
           (cmd == cmdactual)) 
         && (pagprevia >= 0));
@@ -1066,6 +1181,40 @@ const char *UserOptions::getLastStringCmd (int cmdactual, const char *lang, cons
                user.cstr(), connid, avalidator, otropageid, cmdactual, endhtml);
       break;
       }                   
+    case CMD_CALENDAR_YEAR_SHOW:
+      {
+      sprintf (LastCmd, "%s%s/%s/year_show/noop/%s/%s/%s/%d/%d/%d/%ld/%ld/%ld/%s", beghtml, PATH_CGI, TranslateServiceR(aservice), stlang,
+               user.cstr(), connid, avalidator, otropageid, cmdactual, xatoldef (parm1, 1), xatoldef (parm2, 1), xatoldef (parm3, 1), 
+               endhtml);
+      break;      
+      }           
+    case CMD_CALENDAR_MONTH_SHOW:
+      {
+      sprintf (LastCmd, "%s%s/%s/month_show/noop/%s/%s/%s/%d/%d/%d/%ld/%ld/%ld/%s", beghtml, PATH_CGI, TranslateServiceR(aservice), stlang,
+               user.cstr(), connid, avalidator, otropageid, cmdactual, xatoldef (parm1, 1), xatoldef (parm2, 1), xatoldef (parm3, 1), 
+               endhtml);
+      break;      
+      }          
+    case CMD_CALENDAR_DAY_SHOW:
+      {
+      sprintf (LastCmd, "%s%s/%s/day_show/noop/%s/%s/%s/%d/%d/%d/%ld/%ld/%ld/%s", beghtml, PATH_CGI, TranslateServiceR(aservice), stlang,
+               user.cstr(), connid, avalidator, otropageid, cmdactual, xatoldef (parm1, 1), xatoldef (parm2, 1), xatoldef (parm3, 1), 
+               endhtml);
+      break;      
+      }          
+    case CMD_CALENDAR_WEEK_SHOW:
+      {
+      sprintf (LastCmd, "%s%s/%s/week_show/noop/%s/%s/%s/%d/%d/%d/%ld/%ld/%ld/%ld/%s", beghtml, PATH_CGI, TranslateServiceR(aservice), stlang,
+               user.cstr(), connid, avalidator, otropageid, cmdactual, xatoldef (parm1, 1), xatoldef (parm2, 1), xatoldef (parm3, 1),  xatoldef (parm4, 1),
+               endhtml);
+      break;      
+      }                
+    case CMD_MAIN_ROOT:
+      {
+      sprintf (LastCmd, "%s%s/%s/root/noop/%s/%s/%s/%d/%d/%d/%s", beghtml, PATH_CGI, TranslateServiceR(aservice), stlang,
+               user.cstr(), connid, avalidator, otropageid, cmdactual, endhtml);
+      break;
+      }       
     case CMD_CCLIENT_AB: case CMD_CCLIENT_MB_INDEX: case CMD_CCLIENT_MB_SHOW:  
     default:
       {
@@ -1081,64 +1230,5 @@ const char *UserOptions::getLastStringCmd (int cmdactual, const char *lang, cons
   return LastCmd;                
   }  
 
-const char *UserOptions::getSentMailName (void)
-  {
-  if (SentmailName.cstr() == NULL) return DEFOPT_SENTMAILBOX;
-  return SentmailName.cstr();
-  }
   
-void UserOptions::setSentMailName (const char *smname)
-  {
-  if ((smname == NULL) || (strcmp (smname, "") == 0)) return;
-  SentmailName = smname;
-  }
-
-bool UserOptions::getConfirmPurge (void)
-  {
-  return ConfirmPurge;
-  }
   
-void UserOptions::setConfirmPurge (bool b)
-  {
-  ConfirmPurge = b;
-  }
-  
-bool UserOptions::getConfirmLogout (void)
-  {
-  return ConfirmLogout;  
-  }
-  
-void UserOptions::setConfirmLogout (bool b)
-  {
-  ConfirmLogout = b;
-  }
-
-void UserOptions::setLastService (int value)
-  {
-  LastService = value;
-  }
-  
-int UserOptions::getLastService (void)
-  {
-  return LastService;
-  }  
-   
-void UserOptions::setTimeout (int value)
-  {
-  timeout = value;
-  }
-  
-int UserOptions::getTimeout (void)
-  {
-  return timeout;
-  }        
-
-void UserOptions::setMountPoints (const char *amount_points)
-  {
-  xstrncpy (mount_points, CMAXBUFFER, amount_points);
-  }                                                    
-  
-const char *UserOptions::getMountPoints (void)
-  {
-  return mount_points;
-  }                                                      
