@@ -120,6 +120,19 @@ char *ReturnUserAddressbookFileName (const char *basepath, const char *user, con
   return ABuf;
   }  
   
+char *ReturnFileCalendarTemplateUser (TBuffer ABuf)
+  {
+  sprintf (ABuf, "%s/%s", CALENDAR_PATH, USERCALENDARTEMPLATE);
+  return ABuf;
+  }      
+  
+char *ReturnUserCalendarFileName (const char *basepath, const char *user, const char *server, TBuffer ABuf)
+  {
+  TBuffer tmpbuf;
+  sprintf (ABuf, "%s/%s", ReturnUsersDir(basepath, user, server, tmpbuf), USERCALENDAR);
+  return ABuf;
+  }    
+  
 char *ReturnUserSavedMsgFileName (const char *basepath, const char *user, const char *server, TBuffer ABuf)
   {
   TBuffer tmpbuf;
@@ -143,7 +156,7 @@ char *ReturnUserAttachsDir (const char *basepath, const char *user, const char *
   return ABuf;
   }  
   
-bool CreateDir (char *path, mode_t mode)
+bool CreateDir (const char *path, mode_t mode)
   {
   int i;
   bool b;
@@ -619,7 +632,7 @@ void ErrorPage (const char *error)
   } 
 
 //COPIA UN FICHERO, SI EL NUEVO EXISTE NO LO HACE Y DEVUELVE FALSE
-bool CopyFile (char *oldfile, char *newfile)
+bool CopyFile (const char *oldfile, const char *newfile)
   {
   if (FileExists (oldfile) == false) return false;
   if (FileExists (newfile) == true)  return false;
@@ -646,7 +659,7 @@ bool CopyFile (char *oldfile, char *newfile)
   }  
 
 //COPIA SIEMPRE UN FICHERO, SI EL NUEVO EXISTE LO COPIA PONIENDOLE UN PREFIJO
-bool CopyFileWin (char *oldfile, char *newfile)
+bool CopyFileWin (const char *oldfile, const char *newfile)
   {
   TBuffer xnewfile;
   char buffer[CMAXBUFFER];
@@ -854,6 +867,7 @@ bool IsNull (const char *pc)
   
 bool IsGoodValidator (int cmd, int validator, int validatorgood, int service, int lastservice)
   {
+  //DEBUG ("%d,%d,%d,%d,%d", cmd, validator, validatorgood, service, lastservice);
   if (service != lastservice) {return true;}
   if (validator == validatorgood) {return true;}
   if (
@@ -1694,6 +1708,38 @@ int SeparaTokensEnStringList (const char *pc, const char sep, StringList *SL)
   return counter;
   }  
   
+int SeparaTokensEnStringListMax (const char *pc, const char sep, int maxtokens, StringList *SL)
+  {
+  XString XS;
+  char c; 
+  int counter = 0;
+  
+  SL->Clear();
+  XS = "";
+  for (int i = 0; (unsigned int)i < strlen(pc); ++i)
+    {
+    c = pc[i];
+    if (c == sep)
+      {   
+      if (XS.length() > 0) 
+        {
+        ++counter; 
+        if (counter < maxtokens)
+          {
+          SL->Add (XS.cstr());
+          }
+        }
+      XS = "";
+      }
+    else
+      {
+      XS += c;
+      }
+    }
+  if (XS.length() > 0) {++counter; SL->Add (XS.cstr());}
+  return counter;
+  }    
+  
 int CountTokensEnString (const char *pc, const char sep)
   {
   XString XS;
@@ -2194,7 +2240,11 @@ const char *cgienv_GetAllSimpleVarINPUTPC (const char *fnenv, TBuffer abuf, bool
           }
         else
           {
-          if (num_token > 1) {xstrncat (abuf, CMAXBUFFER, "&");}     
+          if (num_token > 1) 
+            {
+            if (LastChar(abuf) == '\n') {abuf[strlen(abuf) - 1]='\0';}
+            xstrncat (abuf, CMAXBUFFER, "&");
+            }     
           xstrncat (abuf, CMAXBUFFER, nomvar);
           xstrncat (abuf, CMAXBUFFER, "=");
           }
@@ -2207,18 +2257,22 @@ const char *cgienv_GetAllSimpleVarINPUTPC (const char *fnenv, TBuffer abuf, bool
         QuitaRetornoCarroDeLinea (linea2);
         if (IsEmpty(linea2)) 
           {
+          //DEBUG ("1 linea='%s'", linea);
           xstrncat (abuf, CMAXBUFFER, linea);
           }
         else
           {  
+          //DEBUG ("2 linea2='%s'", linea2);
           xstrncat (abuf, CMAXBUFFER, linea2);
+          if (num_token > 1) {xstrncat (abuf, CMAXBUFFER, "\n");}          
           }
         }  
       }
     if (Cstrstr (linea, SEPLINE_ENV_INPUT) == 1) {EncontradoLineaSep = true;}
     }    
   fclose (fr);
-  if (LastChar(abuf) == '&') {abuf[strlen(abuf) - 1]='\0';}   
+  if (LastChar(abuf) == '&') {abuf[strlen(abuf) - 1]='\0';}
+  if (LastChar(abuf) == '\n') {abuf[strlen(abuf) - 1]='\0';}   
   //DEBUG ("cgienv_GetAllSimpleVarINPUTPC=--%d--%s--", strlen(abuf), abuf);  
   return abuf;
   }
