@@ -36,14 +36,12 @@
 #if defined(HP)
 #include <hpsecurity.h>
 #include <prot.h>
-#include <db.h>
 #elif defined(LINUX)
-#include <db1/db.h>           
-//#include <db_185.h>           
 #elif defined(SUN)
-#include <db_185.h>           
 #endif
 
+#include "xdb.h"
+
 #define MAXDATUM  256  /* maxima longitud e una entrada passwd en DB */
 #define MAXUSUNOM  20  /* maxima longitud de nombre de usuario */
 #define MAXCAM     10  /* maximo numero de campos en la DB */
